DROP TABLE IF EXISTS array  ;
CREATE TABLE array (
  array_id INTEGER(10) UNSIGNED NOT NULL,
  array_name VARCHAR(50) NOT NULL,
  description TEXT,
  PRIMARY KEY ( array_id ),
  UNIQUE KEY array_name_idx ( array_name )
) ENGINE=MyISAM DEFAULT CHARSET=latin1;

DROP TABLE IF EXISTS probe  ;
CREATE TABLE probe (
  probe_id INTEGER(10) UNSIGNED NOT NULL,
  sequence VARCHAR(40) NOT NULL,
  probe_hit_count INTEGER(2) UNSIGNED NOT NULL,
  PRIMARY KEY ( probe_id ),
  KEY probe_hit_count_idx ( probe_hit_count ),
  KEY probe_sequence_idx ( sequence )
) ENGINE=MyISAM DEFAULT CHARSET=latin1;

DROP TABLE IF EXISTS chromosome  ;
CREATE TABLE chromosome (
  chromosome_id INTEGER(10) UNSIGNED NOT NULL,
  name VARCHAR(40) NOT NULL,
  length INTEGER(10) UNSIGNED NOT NULL,
  PRIMARY KEY ( chromosome_id ),
  UNIQUE KEY name_idx ( name )
) ENGINE=MyISAM DEFAULT CHARSET=latin1;

DROP TABLE IF EXISTS synonym  ;
CREATE TABLE synonym (
  synonym_id INTEGER(10) UNSIGNED NOT NULL,
  synonym VARCHAR(40) NOT NULL,
  KEY syn_id_idx ( synonym_id ),
  KEY syn_idx ( synonym )
) ENGINE=MyISAM DEFAULT CHARSET=latin1;

DROP TABLE IF EXISTS probeset  ;
CREATE TABLE probeset (
  probeset_id INTEGER(10) UNSIGNED NOT NULL,
  stable_id VARCHAR(40) NOT NULL,
  array_id INTEGER(10) UNSIGNED NOT NULL,
  array_name VARCHAR(50) NOT NULL,
  probe_count INTEGER(10) UNSIGNED NOT NULL,
  hit_score TINYINT(2) UNSIGNED NOT NULL DEFAULT 0,
  gene_score TINYINT(2) UNSIGNED NOT NULL DEFAULT 0,
  transcript_score TINYINT(2) UNSIGNED NOT NULL DEFAULT 0,
  exon_score TINYINT(2) UNSIGNED NOT NULL DEFAULT 0,
  est_gene_score TINYINT(2) UNSIGNED NOT NULL DEFAULT 0,
  est_transcript_score TINYINT(2) UNSIGNED NOT NULL DEFAULT 0,
  est_exon_score TINYINT(2) UNSIGNED NOT NULL DEFAULT 0,
  prediction_transcript_score TINYINT(2) UNSIGNED NOT NULL DEFAULT 0,
  prediction_exon_score TINYINT(2) UNSIGNED NOT NULL DEFAULT 0,
  protein_score TINYINT(2) UNSIGNED NOT NULL DEFAULT 0,
  domain_score TINYINT(2) UNSIGNED NOT NULL DEFAULT 0,
  PRIMARY KEY ( probeset_id ),
  KEY probeset_name_idx ( stable_id, array_id ),
  KEY array_name_idx ( array_name )
) ENGINE=MyISAM DEFAULT CHARSET=latin1;

DROP TABLE IF EXISTS probemap  ;
CREATE TABLE probemap (
  probeset_id INTEGER(10) UNSIGNED NOT NULL,
  probe_index INTEGER(10) UNSIGNED NOT NULL,
  probe_id INTEGER(10) UNSIGNED NOT NULL,
  PRIMARY KEY ( probeset_id, probe_index, probe_id ),
  KEY probemap_probeset ( probeset_id ),
  KEY probemap_probe ( probe_id )
) ENGINE=MyISAM DEFAULT CHARSET=latin1;

DROP TABLE IF EXISTS hit  ;
CREATE TABLE hit (
  hit_id INTEGER(10) UNSIGNED NOT NULL,
  probe_id INTEGER(10) UNSIGNED NOT NULL,
  chromosome_id INTEGER(10) UNSIGNED NOT NULL,
  chromosome_name VARCHAR(40) NOT NULL,
  start INTEGER UNSIGNED NOT NULL,
  end INTEGER UNSIGNED NOT NULL,
  strand TINYINT(2) NOT NULL,
  PRIMARY KEY ( hit_id ),
  KEY hit_probe_idx ( probe_id ),
  KEY hit_namestrandstart_idx ( chromosome_name, strand, start )
) ENGINE=MyISAM DEFAULT CHARSET=latin1;

DROP TABLE IF EXISTS gene  ;
CREATE TABLE gene (
  gene_id INTEGER(10) UNSIGNED NOT NULL,
  stable_id VARCHAR(128) NOT NULL,
  chromosome_id INTEGER(10) UNSIGNED NOT NULL,
  chromosome_name VARCHAR(40) NOT NULL,
  start INTEGER UNSIGNED NOT NULL,
  end INTEGER UNSIGNED NOT NULL,
  strand TINYINT(2),
  biotype VARCHAR(40),
  status VARCHAR(128),
  description TEXT,
  synonym_id INTEGER(10) UNSIGNED DEFAULT NULL,
  external_db_id INTEGER(10) UNSIGNED DEFAULT NULL,
  db_display_name VARCHAR(255) DEFAULT NULL,
  symbol VARCHAR(128) DEFAULT NULL,
  symbol_description TEXT DEFAULT NULL,
  analysis_name VARCHAR(128) DEFAULT NULL,
  PRIMARY KEY ( gene_id ),
  UNIQUE KEY gene_stable_idx ( stable_id ),
  KEY gene_chr_name_idx ( chromosome_name ),
  KEY gene_start_index ( start ),
  KEY gene_end_idx ( end ),
  KEY gene_strand_idx ( strand ),
  KEY synonym_idx ( synonym_id ),
  KEY symbol ( symbol )
) ENGINE=MyISAM DEFAULT CHARSET=latin1;

DROP TABLE IF EXISTS hit_gene  ;
CREATE TABLE hit_gene (
  hit_id INTEGER(10) UNSIGNED NOT NULL,
  gene_id INTEGER(10) UNSIGNED NOT NULL,
  PRIMARY KEY ( hit_id, gene_id ),
  KEY hit_gehit ( hit_id ),
  KEY hit_gene ( gene_id )
) ENGINE=MyISAM DEFAULT CHARSET=latin1;

DROP TABLE IF EXISTS exon  ;
CREATE TABLE exon (
  exon_id INTEGER(10) UNSIGNED NOT NULL,
  stable_id VARCHAR(128) NOT NULL,
  chromosome_id INTEGER(10) UNSIGNED NOT NULL,
  chromosome_name VARCHAR(40) NOT NULL,
  start INTEGER(10) UNSIGNED NOT NULL,
  end INTEGER(10) UNSIGNED NOT NULL,
  strand TINYINT(2) NOT NULL,
  phase TINYINT(2) NOT NULL,
  end_phase TINYINT(2) NOT NULL,
  sequence TEXT,
  PRIMARY KEY ( exon_id ),
  UNIQUE KEY exon_stable_idx ( stable_id ),
  KEY exon_chr_name_idx ( chromosome_name ),
  KEY exon_start_index ( start ),
  KEY exon_end_idx ( end ),
  KEY exon_strand_idx ( strand )
) ENGINE=MyISAM DEFAULT CHARSET=latin1;

DROP TABLE IF EXISTS hit_exon  ;
CREATE TABLE hit_exon (
  hit_id INTEGER(10) UNSIGNED NOT NULL,
  exon_id INTEGER(10) UNSIGNED NOT NULL,
  PRIMARY KEY ( hit_id, exon_id ),
  KEY hit_exhit ( hit_id ),
  KEY hit_exon ( exon_id )
) ENGINE=MyISAM DEFAULT CHARSET=latin1;

DROP TABLE IF EXISTS transcript  ;
CREATE TABLE transcript (
  transcript_id INTEGER(10) UNSIGNED NOT NULL,
  stable_id VARCHAR(128) NOT NULL,
  gene_id INTEGER(10) UNSIGNED NOT NULL,
  chromosome_id INTEGER(10) UNSIGNED NOT NULL,
  chromosome_name VARCHAR(40) NOT NULL,
  start INTEGER UNSIGNED NOT NULL,
  end INTEGER UNSIGNED NOT NULL,
  strand TINYINT(2) NOT NULL,
  biotype VARCHAR(40) NOT NULL,
  status VARCHAR(128),
  description TEXT,
  synonym_id INTEGER(10) UNSIGNED DEFAULT NULL,
  external_db_id INTEGER(10) UNSIGNED DEFAULT NULL,
  db_display_name VARCHAR(255) DEFAULT NULL,
  symbol VARCHAR(128) DEFAULT NULL,
  symbol_description TEXT DEFAULT NULL,
  translation_start INTEGER(10),
  translation_start_exon INTEGER(10),
  translation_end INTEGER(10),
  translation_end_exon INTEGER(10),
  analysis_name VARCHAR(128) DEFAULT NULL,
  PRIMARY KEY ( transcript_id ),
  UNIQUE KEY transcript_stable_idx ( stable_id ),
  KEY transcript_gene_idx ( gene_id ),
  KEY transcript_chr_name_idx ( chromosome_name ),
  KEY transcript_start_exon_idx ( translation_start_exon ),
  KEY transcript_end_exon_idx ( translation_end_exon ),
  KEY transcript_strand_idx ( strand ),
  KEY synonym_idx ( synonym_id )
) ENGINE=MyISAM DEFAULT CHARSET=latin1;

DROP TABLE IF EXISTS protein  ;
CREATE TABLE protein (
  protein_id INTEGER(10) UNSIGNED NOT NULL,
  stable_id VARCHAR(40) NOT NULL,
  gene_id INTEGER(10) UNSIGNED NOT NULL,
  transcript_id INTEGER(10) UNSIGNED NOT NULL,
  chromosome_id INTEGER(10) UNSIGNED NOT NULL,
  chromosome_name VARCHAR(40) NOT NULL,
  start INTEGER UNSIGNED NOT NULL,
  end INTEGER UNSIGNED NOT NULL,
  strand TINYINT(2),
  PRIMARY KEY ( protein_id ),
  UNIQUE KEY protein_stable_idx ( stable_id ),
  KEY gene_idx ( gene_id ),
  KEY transcript_idx ( transcript_id ),
  KEY pro_namestrandstart_idx ( chromosome_name, strand, start, end )
) ENGINE=MyISAM DEFAULT CHARSET=latin1;

DROP TABLE IF EXISTS domain  ;
CREATE TABLE domain (
  hit_id INTEGER(10) UNSIGNED NOT NULL,
  stable_id VARCHAR(7) NOT NULL,
  symbol VARCHAR(40) NOT NULL,
  description VARCHAR(100) NOT NULL,
  model_length MEDIUMINT(8) UNSIGNED,
  type TINYTEXT,
  protein_id INTEGER(10) UNSIGNED NOT NULL,
  seq_start INTEGER UNSIGNED NOT NULL,
  seq_end INTEGER UNSIGNED NOT NULL,
  hmm_start INTEGER UNSIGNED NOT NULL,
  hmm_end INTEGER UNSIGNED NOT NULL,
  bit_score DOUBLE,
  evalue DOUBLE,
  chromosome_id INTEGER(10) UNSIGNED NOT NULL,
  chromosome_name VARCHAR(40) NOT NULL,
  start INTEGER UNSIGNED NOT NULL,
  end INTEGER UNSIGNED NOT NULL,
  strand TINYINT(2),
  PRIMARY KEY ( hit_id ),
  KEY protein_idx ( protein_id ),
  KEY stable_idx ( stable_id ),
  KEY dom_namestrandstart_idx ( chromosome_name, strand, start, end )
) ENGINE=MyISAM DEFAULT CHARSET=latin1;

DROP TABLE IF EXISTS hit_transcript  ;
CREATE TABLE hit_transcript (
  hit_id INTEGER(10) UNSIGNED NOT NULL,
  transcript_id INTEGER(10) UNSIGNED NOT NULL,
  PRIMARY KEY ( hit_id, transcript_id ),
  KEY hit_trhit ( hit_id ),
  KEY hit_transcript ( transcript_id )
) ENGINE=MyISAM DEFAULT CHARSET=latin1;

DROP TABLE IF EXISTS hit_protein  ;
CREATE TABLE hit_protein (
  hit_id INTEGER(10) UNSIGNED NOT NULL,
  protein_id INTEGER(10) UNSIGNED NOT NULL,
  PRIMARY KEY ( hit_id, protein_id ),
  KEY hit_prhit ( hit_id ),
  KEY hit_prot ( protein_id )
) ENGINE=MyISAM DEFAULT CHARSET=latin1;

DROP TABLE IF EXISTS hit_domain  ;
CREATE TABLE hit_domain (
  hit_id INTEGER(10) UNSIGNED NOT NULL,
  domain_id INTEGER(10) UNSIGNED NOT NULL,
  PRIMARY KEY ( hit_id, domain_id ),
  KEY hit_dohit ( hit_id ),
  KEY hit_domai ( domain_id )
) ENGINE=MyISAM DEFAULT CHARSET=latin1;

DROP TABLE IF EXISTS transcript_hit  ;
CREATE TABLE transcript_hit (
  probe_id INTEGER(10) UNSIGNED NOT NULL,
  transcript_id INTEGER(10) UNSIGNED NOT NULL,
  transcript_start INTEGER UNSIGNED NOT NULL,
  transcript_end INTEGER UNSIGNED NOT NULL,
  KEY th_probe_idx ( probe_id ),
  KEY th_transcript_idx ( transcript_id )
) ENGINE=MyISAM DEFAULT CHARSET=latin1;

DROP TABLE IF EXISTS exon_transcript  ;
CREATE TABLE exon_transcript (
  exon_id INTEGER(10) UNSIGNED NOT NULL,
  transcript_id INTEGER(10) UNSIGNED NOT NULL,
  rank INTEGER(10) UNSIGNED NOT NULL,
  PRIMARY KEY ( exon_id, transcript_id, rank ),
  KEY exon_transcript_transcript_idx ( transcript_id ),
  KEY exon_transcript_exon_idx ( exon_id )
) ENGINE=MyISAM DEFAULT CHARSET=latin1;

DROP TABLE IF EXISTS est_gene  ;
CREATE TABLE est_gene (
  gene_id INTEGER(10) UNSIGNED NOT NULL,
  stable_id VARCHAR(128) NOT NULL,
  chromosome_id INTEGER(10) UNSIGNED NOT NULL,
  chromosome_name VARCHAR(40) NOT NULL,
  start INTEGER UNSIGNED NOT NULL,
  end INTEGER UNSIGNED NOT NULL,
  strand TINYINT(2),
  biotype VARCHAR(40),
  status VARCHAR(128),
  description TEXT,
  synonym_id INTEGER(10) UNSIGNED DEFAULT NULL,
  external_db_id INTEGER(10) UNSIGNED DEFAULT NULL,
  db_display_name VARCHAR(255) DEFAULT NULL,
  symbol VARCHAR(128) DEFAULT NULL,
  symbol_description TEXT DEFAULT NULL,
  PRIMARY KEY ( gene_id ),
  UNIQUE KEY gene_stable_idx ( stable_id ),
  KEY gene_chr_name_idx ( chromosome_name ),
  KEY gene_start_index ( start ),
  KEY gene_end_idx ( end ),
  KEY gene_strand_idx ( strand ),
  KEY synonym_idx ( synonym_id )
) ENGINE=MyISAM DEFAULT CHARSET=latin1;

DROP TABLE IF EXISTS hit_est_gene  ;
CREATE TABLE hit_est_gene (
  hit_id INTEGER(10) UNSIGNED NOT NULL,
  gene_id INTEGER(10) UNSIGNED NOT NULL,
  PRIMARY KEY ( hit_id, gene_id ),
  KEY hit_eghit ( hit_id ),
  KEY hit_egene ( gene_id )
) ENGINE=MyISAM DEFAULT CHARSET=latin1;

DROP TABLE IF EXISTS est_exon  ;
CREATE TABLE est_exon (
  exon_id INTEGER(10) UNSIGNED NOT NULL,
  stable_id VARCHAR(128),
  chromosome_id INTEGER(10) UNSIGNED NOT NULL,
  chromosome_name VARCHAR(40) NOT NULL,
  start INTEGER(10) UNSIGNED NOT NULL,
  end INTEGER(10) UNSIGNED NOT NULL,
  strand TINYINT(2) NOT NULL,
  phase TINYINT(2) NOT NULL,
  end_phase TINYINT(2) NOT NULL,
  sequence TEXT,
  PRIMARY KEY ( exon_id ),
  UNIQUE KEY exon_stable_idx ( stable_id ),
  KEY exon_chr_name_idx ( chromosome_name ),
  KEY exon_start_index ( start ),
  KEY exon_end_idx ( end ),
  KEY exon_strand_idx ( strand )
) ENGINE=MyISAM DEFAULT CHARSET=latin1;

DROP TABLE IF EXISTS hit_est_exon  ;
CREATE TABLE hit_est_exon (
  hit_id INTEGER(10) UNSIGNED NOT NULL,
  exon_id INTEGER(10) UNSIGNED NOT NULL,
  PRIMARY KEY ( hit_id, exon_id ),
  KEY hit_eehit ( hit_id ),
  KEY hit_eexon ( exon_id )
) ENGINE=MyISAM DEFAULT CHARSET=latin1;

DROP TABLE IF EXISTS est_transcript  ;
CREATE TABLE est_transcript (
  transcript_id INTEGER(10) UNSIGNED NOT NULL,
  stable_id VARCHAR(128) NOT NULL,
  gene_id INTEGER(10) UNSIGNED NOT NULL,
  chromosome_id INTEGER(10) UNSIGNED NOT NULL,
  chromosome_name VARCHAR(40) NOT NULL,
  start INTEGER UNSIGNED NOT NULL,
  end INTEGER UNSIGNED NOT NULL,
  strand TINYINT(2) NOT NULL,
  biotype VARCHAR(40) NOT NULL,
  status VARCHAR(128),
  description TEXT,
  synonym_id INTEGER(10) UNSIGNED DEFAULT NULL,
  external_db_id INTEGER(10) UNSIGNED DEFAULT NULL,
  db_display_name VARCHAR(255) DEFAULT NULL,
  symbol VARCHAR(128) DEFAULT NULL,
  symbol_description TEXT DEFAULT NULL,
  translation_start INTEGER(10),
  translation_start_exon INTEGER(10),
  translation_end INTEGER(10),
  translation_end_exon INTEGER(10),
  PRIMARY KEY ( transcript_id ),
  UNIQUE KEY stable_idx ( stable_id ),
  KEY chr_name_idx ( chromosome_name ),
  KEY gene_idx ( gene_id ),
  KEY transcript_start_exon_idx ( translation_start_exon ),
  KEY transcript_end_exon_idx ( translation_end_exon ),
  KEY start_index ( start ),
  KEY end_idx ( end ),
  KEY strand_idx ( strand ),
  KEY synonym_idx ( synonym_id )
) ENGINE=MyISAM DEFAULT CHARSET=latin1;

DROP TABLE IF EXISTS hit_est_transcript  ;
CREATE TABLE hit_est_transcript (
  hit_id INTEGER(10) UNSIGNED NOT NULL,
  transcript_id INTEGER(10) UNSIGNED NOT NULL,
  PRIMARY KEY ( hit_id, transcript_id ),
  KEY hit_ethit ( hit_id ),
  KEY hit_etranscript ( transcript_id )
) ENGINE=MyISAM DEFAULT CHARSET=latin1;

DROP TABLE IF EXISTS est_exon_transcript  ;
CREATE TABLE est_exon_transcript (
  exon_id INTEGER(10) UNSIGNED NOT NULL,
  transcript_id INTEGER(10) UNSIGNED NOT NULL,
  rank INTEGER(10) UNSIGNED NOT NULL,
  PRIMARY KEY ( exon_id, transcript_id, rank ),
  KEY exon_transcript_transcript_idx ( transcript_id ),
  KEY exon_transcript_exon_idx ( exon_id )
) ENGINE=MyISAM DEFAULT CHARSET=latin1;

DROP TABLE IF EXISTS prediction_transcript  ;
CREATE TABLE prediction_transcript (
  transcript_id INTEGER(10) UNSIGNED NOT NULL,
  stable_id VARCHAR(80) NOT NULL,
  chromosome_id INTEGER(10) UNSIGNED NOT NULL,
  chromosome_name VARCHAR(40) NOT NULL,
  start INTEGER(10) UNSIGNED NOT NULL,
  end INTEGER(10) UNSIGNED NOT NULL,
  strand TINYINT(2) NOT NULL,
  PRIMARY KEY ( transcript_id ),
  UNIQUE KEY pt_stable_idx ( stable_id ),
  KEY pt_chr_name_idx ( chromosome_name ),
  KEY pt_start_index ( start ),
  KEY pt_end_idx ( end ),
  KEY pt_strand_idx ( strand )
) ENGINE=MyISAM DEFAULT CHARSET=latin1;

DROP TABLE IF EXISTS hit_prediction_transcript  ;
CREATE TABLE hit_prediction_transcript (
  hit_id INTEGER(10) UNSIGNED NOT NULL,
  transcript_id INTEGER(10) UNSIGNED NOT NULL,
  PRIMARY KEY ( hit_id, transcript_id ),
  KEY hit_pthit ( hit_id ),
  KEY hit_ptranscript ( transcript_id )
) ENGINE=MyISAM DEFAULT CHARSET=latin1;

DROP TABLE IF EXISTS prediction_exon  ;
CREATE TABLE prediction_exon (
  exon_id INTEGER(10) UNSIGNED NOT NULL,
  transcript_id INTEGER(10) UNSIGNED NOT NULL,
  exon_rank INTEGER(10) UNSIGNED NOT NULL,
  chromosome_id INTEGER(10) UNSIGNED NOT NULL,
  chromosome_name VARCHAR(40) NOT NULL,
  start INTEGER(10) UNSIGNED NOT NULL,
  end INTEGER(10) UNSIGNED NOT NULL,
  strand TINYINT(2) NOT NULL,
  start_phase TINYINT(4),
  sequence TEXT,
  PRIMARY KEY ( exon_id ),
  KEY pe_transcript_idx ( transcript_id ),
  KEY pe_chr_name_idx ( chromosome_name ),
  KEY pe_start_index ( start ),
  KEY pe_end_idx ( end ),
  KEY pe_strand_idx ( strand )
) ENGINE=MyISAM DEFAULT CHARSET=latin1;

DROP TABLE IF EXISTS hit_prediction_exon  ;
CREATE TABLE hit_prediction_exon (
  hit_id INTEGER(10) UNSIGNED NOT NULL,
  exon_id INTEGER(10) UNSIGNED NOT NULL,
  PRIMARY KEY ( hit_id, exon_id ),
  KEY hit_pehit ( hit_id ),
  KEY hit_pexon ( exon_id )
) ENGINE=MyISAM DEFAULT CHARSET=latin1;

DROP TABLE IF EXISTS variation  ;
CREATE TABLE variation (
  variation_feature_id INTEGER(10)    UNSIGNED NOT NULL,
  stable_id VARCHAR(255)   DEFAULT NULL,
  chromosome_id INTEGER(10)    UNSIGNED NOT NULL,
  start INTEGER(11)    UNSIGNED NOT NULL,
  end INTEGER(11)    UNSIGNED NOT NULL,
  strand TINYINT(4)     NOT NULL,
  allele_string VARCHAR(50000) DEFAULT NULL,
  allele_freq FLOAT          DEFAULT NULL,
  minor_allele CHAR(1)        DEFAULT NULL,
  attrib_class TEXT,
  source VARCHAR(255)   DEFAULT NULL,
  validation_status SET('cluster','freq','submitter','doublehit','hapmap','1000Genome','precious') DEFAULT NULL,
  PRIMARY KEY ( variation_feature_id ),
  KEY pos_idx ( start, end, strand ),
  KEY variation_stable_idx ( stable_id )
) ENGINE=MyISAM DEFAULT CHARSET=latin1;

DROP TABLE IF EXISTS transcript_variation  ;
CREATE TABLE transcript_variation (
  variation_feature_id INTEGER(11)  UNSIGNED NOT NULL,
  consequence_types SET('splice_acceptor_variant','splice_donor_variant','complex_change_in_transcript','stop_lost',
                         'coding_sequence_variant','non_synonymous_codon','stop_gained','synonymous_codon','frameshift_variant',
                         'nc_transcript_variant','mature_miRNA_variant','NMD_transcript_variant','5_prime_UTR_variant',
                         '3_prime_UTR_variant','incomplete_terminal_codon_variant','intron_variant','splice_region_variant',
                         '5KB_downstream_variant','500B_downstream_variant','5KB_upstream_variant','2KB_upstream_variant',
                         'initiator_codon_change','stop_retained_variant','inframe_codon_gain','inframe_codon_loss','pre_miRNA_variant') DEFAULT NULL,
  pep_allele_string TEXT,
  translation_start INTEGER(11)  UNSIGNED DEFAULT NULL,
  translation_end INTEGER(11)  UNSIGNED DEFAULT NULL,
  sift_score FLOAT        DEFAULT NULL,
  polyphen_score FLOAT        DEFAULT NULL,
  feature_stable_id VARCHAR(128) DEFAULT NULL,
  KEY variation_feature_idx ( variation_feature_id ),
  KEY feature_idx ( feature_stable_id )
) ENGINE=MyISAM DEFAULT CHARSET=latin1;

