
DELIMITER $$

DROP PROCEDURE IF EXISTS tokeniser$$
CREATE PROCEDURE tokeniser( outTableName TEXT, inputString TEXT )
BEGIN
  DECLARE idx INT DEFAULT 1 ;
  DECLARE remainder TEXT;
  DECLARE tok VARCHAR( 80 ) ;
  SET remainder = inputString ;
  WHILE CHAR_LENGTH( remainder ) > 0 AND idx > 0 DO
    SET idx = INSTR( remainder, ',' ) ;
    IF idx = 0 THEN
      SET tok = remainder ;
    ELSE
      SET tok = LEFT( remainder, idx - 1 ) ;
    END IF;
    SET remainder = SUBSTRING( remainder, idx + 1 ) ;
    SET @s = CONCAT( 'INSERT INTO ' , outTableName , ' VALUES( ', quote( tok ), ' )' ) ;
    PREPARE stmt FROM @s;
    EXECUTE stmt;
  END WHILE ;
END$$

DROP PROCEDURE IF EXISTS env$$
CREATE PROCEDURE env()
BEGIN
  DECLARE dbName TEXT ;
  DROP TEMPORARY TABLE IF EXISTS tmp_data ;
  CREATE TEMPORARY TABLE tmp_data (
     k VARCHAR(80),
     v TEXT ) ;
  SELECT DATABASE() INTO dbName ;
  INSERT INTO tmp_data ( k, v ) VALUES ( 'current_database', dbName ) ;
  INSERT INTO tmp_data( k, v ) VALUES ( 'db_version', VERSION() ) ;
  INSERT INTO tmp_data
      SELECT CONCAT( dbName, '_charset' ), DEFAULT_CHARACTER_SET_NAME FROM information_schema.SCHEMATA WHERE SCHEMA_NAME = dbName ;
  INSERT INTO tmp_data
      SELECT CONCAT( dbName, '_collation' ), DEFAULT_COLLATION_NAME FROM information_schema.SCHEMATA WHERE SCHEMA_NAME = dbName ;
  INSERT INTO tmp_data
      SELECT CONCAT( TABLE_NAME, '_rows' ), TABLE_ROWS FROM information_schema.TABLES WHERE TABLE_SCHEMA = dbName ;
  INSERT INTO tmp_data
      SELECT CONCAT( TABLE_NAME, '_collation' ), TABLE_COLLATION FROM information_schema.TABLES WHERE TABLE_SCHEMA = dbName ;
  INSERT INTO tmp_data
      SELECT CONCAT( ROUTINE_NAME ), ROUTINE_TYPE FROM information_schema.ROUTINES WHERE ROUTINE_SCHEMA = dbName ;
  SELECT * FROM tmp_data ;
END$$


DROP PROCEDURE IF EXISTS all_arrays$$
CREATE PROCEDURE all_arrays(  )
BEGIN
  SELECT array.array_id, array.array_name, array.description
    FROM array
    ORDER BY array_id ASC ;
END$$

DROP PROCEDURE IF EXISTS array_details$$
CREATE PROCEDURE array_details( ids TEXT )
BEGIN
  DROP TEMPORARY TABLE IF EXISTS tmp_data ;
  CREATE TEMPORARY TABLE tmp_data (
    ids VARCHAR( 80 ),
    INDEX USING HASH ( ids )
  ) ENGINE=MEMORY ;
  CALL tokeniser( 'tmp_data', ids ) ;
  SELECT tmp_data.ids AS IN1, array.array_id, array.array_name, array.description
    FROM tmp_data
      JOIN array ON ( array.array_name = tmp_data.ids ) ;
END$$


DROP PROCEDURE IF EXISTS array_to_probeset$$
CREATE PROCEDURE array_to_probeset( arraynames TEXT )
BEGIN
  DROP TEMPORARY TABLE IF EXISTS tmp_data ;
  CREATE TEMPORARY TABLE tmp_data (
    ids VARCHAR( 80 ),
    INDEX USING HASH ( ids )
  ) ENGINE=MEMORY ;
  CALL tokeniser( 'tmp_data', arraynames ) ;
  SELECT DISTINCT array.array_name AS IN1, probeset.probeset_id, probeset.stable_id, probeset.array_id, probeset.array_name,
        probeset.probe_count, probeset.hit_score, probeset.gene_score, probeset.transcript_score,
        probeset.exon_score, probeset.est_gene_score, probeset.est_transcript_score, probeset.est_exon_score,
        probeset.prediction_transcript_score, probeset.prediction_exon_score, probeset.protein_score, probeset.domain_score
  FROM tmp_data
    JOIN array ON ( tmp_data.ids = array.array_name )
    JOIN probeset ON ( probeset.array_id = array.array_id )
 ;
END$$


DROP PROCEDURE IF EXISTS probesets_in_range$$
CREATE PROCEDURE probesets_in_range( arrayname TEXT, chr VARCHAR(40), qstart INTEGER(10), qstop INTEGER(10), qstrand TINYINT(2) )
BEGIN
  DECLARE probeid, done INT DEFAULT 0 ;
  DECLARE probe_cursor CURSOR FOR SELECT h.probe_id FROM  hit AS h WHERE chromosome_name=chr AND h.start >= qstart AND h.start <= qstop AND strand = qstrand ORDER BY start ASC ;
  DECLARE CONTINUE HANDLER FOR SQLSTATE '02000' SET done = 1 ;
  DECLARE CONTINUE HANDLER FOR NOT FOUND SET done = 1;
  DECLARE EXIT HANDLER FOR SQLEXCEPTION
  BEGIN
    DROP TEMPORARY TABLE IF EXISTS tmp_probesets ;
    CLOSE probe_cursor ;
  END ;
  CREATE TEMPORARY TABLE tmp_probesets ( probeset_id INTEGER(10) UNSIGNED NOT NULL, INDEX USING HASH ( probeset_id ) ) ENGINE=MEMORY ;
  OPEN probe_cursor ;
  REPEAT
    FETCH probe_cursor INTO probeid ;
    IF NOT done THEN
      INSERT INTO tmp_probesets
        SELECT probeset.probeset_id
          FROM probeset
          JOIN probemap USING ( probeset_id )
          WHERE array_name=arrayname AND probemap.probe_id = probeid ;
    END IF ;
  UNTIL done END REPEAT ;
  CLOSE probe_cursor ;
  SELECT DISTINCT probeset.* FROM tmp_probesets JOIN probeset USING( probeset_id ) ORDER BY stable_id ;
  DROP TEMPORARY TABLE tmp_probesets ;
END$$


DROP PROCEDURE IF EXISTS all_probesets$$
CREATE PROCEDURE all_probesets( arrayname VARCHAR(40) )
BEGIN
  SELECT probeset.probeset_id, probeset.stable_id, probeset.array_id, probeset.array_name, 
       probeset.probe_count, probeset.hit_score, probeset.gene_score, probeset.transcript_score, 
       probeset.exon_score, probeset.est_gene_score, probeset.est_transcript_score, probeset.est_exon_score, 
       probeset.prediction_transcript_score, probeset.prediction_exon_score, probeset.protein_score, probeset.domain_score
    FROM probeset
    WHERE array_name = arrayname
    ORDER BY probeset_id ASC ;
END$$

DROP PROCEDURE IF EXISTS probeset_details$$
CREATE PROCEDURE probeset_details( arrayname VARCHAR(40), ids TEXT )
BEGIN
  DROP TEMPORARY TABLE IF EXISTS tmp_data ;
  CREATE TEMPORARY TABLE tmp_data (
    ids VARCHAR( 80 ),
    INDEX USING HASH ( ids )
  ) ENGINE=MEMORY ;
  CALL tokeniser( 'tmp_data', ids ) ;
  SELECT tmp_data.ids AS IN1, probeset.probeset_id, probeset.stable_id, probeset.array_id, probeset.array_name, 
       probeset.probe_count, probeset.hit_score, probeset.gene_score, probeset.transcript_score, 
       probeset.exon_score, probeset.est_gene_score, probeset.est_transcript_score, probeset.est_exon_score, 
       probeset.prediction_transcript_score, probeset.prediction_exon_score, probeset.protein_score, probeset.domain_score
    FROM tmp_data
      JOIN probeset ON ( probeset.stable_id = tmp_data.ids )
    WHERE array_name = arrayname ;
END$$


DROP PROCEDURE IF EXISTS probeset_to_gene$$
CREATE PROCEDURE probeset_to_gene( arrayname TEXT, probesetnames TEXT )
BEGIN
  DROP TEMPORARY TABLE IF EXISTS tmp_data ;
  CREATE TEMPORARY TABLE tmp_data (
    ids VARCHAR( 80 ),
    INDEX USING HASH ( ids )
  ) ENGINE=MEMORY ;
  CALL tokeniser( 'tmp_data', probesetnames ) ;
  SELECT DISTINCT probeset.stable_id AS IN1, gene.gene_id, gene.stable_id, gene.chromosome_id, gene.chromosome_name,
        gene.start, gene.end, gene.strand, gene.biotype,
        gene.status, gene.description, gene.synonym_id, gene.external_db_id,
        gene.db_display_name, gene.symbol, gene.symbol_description, gene.analysis_name
  FROM tmp_data
    JOIN probeset ON ( tmp_data.ids = probeset.stable_id AND probeset.array_name = arrayname )
    JOIN probemap ON ( probeset.probeset_id = probemap.probeset_id )
    JOIN hit ON ( probemap.probe_id = hit.probe_id )
    JOIN hit_gene ON ( hit.hit_id = hit_gene.hit_id )
    JOIN gene ON ( gene.gene_id = hit_gene.gene_id )
 ;
END$$


DROP PROCEDURE IF EXISTS probeset_to_transcript$$
CREATE PROCEDURE probeset_to_transcript( arrayname TEXT, probesetnames TEXT )
BEGIN
  DROP TEMPORARY TABLE IF EXISTS tmp_data ;
  CREATE TEMPORARY TABLE tmp_data (
    ids VARCHAR( 80 ),
    INDEX USING HASH ( ids )
  ) ENGINE=MEMORY ;
  CALL tokeniser( 'tmp_data', probesetnames ) ;
  SELECT DISTINCT probeset.stable_id AS IN1, transcript.transcript_id, transcript.stable_id, transcript.gene_id, transcript.chromosome_id,
        transcript.chromosome_name, transcript.start, transcript.end, transcript.strand,
        transcript.biotype, transcript.status, transcript.description, transcript.synonym_id,
        transcript.external_db_id, transcript.db_display_name, transcript.symbol, transcript.symbol_description,
        transcript.translation_start, transcript.translation_start_exon, transcript.translation_end, transcript.translation_end_exon,
        transcript.analysis_name
  FROM tmp_data
    JOIN probeset ON ( tmp_data.ids = probeset.stable_id AND probeset.array_name = arrayname )
    JOIN probemap ON ( probeset.probeset_id = probemap.probeset_id )
    JOIN hit ON ( probemap.probe_id = hit.probe_id )
    JOIN hit_transcript ON ( hit.hit_id = hit_transcript.hit_id )
    JOIN transcript ON ( transcript.transcript_id = hit_transcript.transcript_id )
 ;
END$$


DROP PROCEDURE IF EXISTS probeset_to_cdnatranscript$$
CREATE PROCEDURE probeset_to_cdnatranscript( arrayname TEXT, probesetnames TEXT )
BEGIN
  DROP TEMPORARY TABLE IF EXISTS tmp_data ;
  CREATE TEMPORARY TABLE tmp_data (
    ids VARCHAR( 80 ),
    INDEX USING HASH ( ids )
  ) ENGINE=MEMORY ;
  CALL tokeniser( 'tmp_data', probesetnames ) ;
  SELECT DISTINCT probeset.stable_id AS IN1, transcript_hit.transcript_start, transcript_hit.transcript_end, transcript.transcript_id, transcript.stable_id,
        transcript.gene_id, transcript.chromosome_id, transcript.chromosome_name, transcript.start,
        transcript.end, transcript.strand, transcript.biotype, transcript.status,
        transcript.description, transcript.synonym_id, transcript.external_db_id, transcript.db_display_name,
        transcript.symbol, transcript.symbol_description, transcript.translation_start, transcript.translation_start_exon,
        transcript.translation_end, transcript.translation_end_exon, transcript.analysis_name
  FROM tmp_data
    JOIN probeset ON ( tmp_data.ids = probeset.stable_id AND probeset.array_name = arrayname )
    JOIN probemap ON ( probeset.probeset_id = probemap.probeset_id )
    JOIN transcript_hit ON ( probemap.probe_id = transcript_hit.probe_id )
    JOIN transcript ON ( transcript.transcript_id = transcript_hit.transcript_id )
 ;
END$$


DROP PROCEDURE IF EXISTS probeset_to_exon$$
CREATE PROCEDURE probeset_to_exon( arrayname TEXT, probesetnames TEXT )
BEGIN
  DROP TEMPORARY TABLE IF EXISTS tmp_data ;
  CREATE TEMPORARY TABLE tmp_data (
    ids VARCHAR( 80 ),
    INDEX USING HASH ( ids )
  ) ENGINE=MEMORY ;
  CALL tokeniser( 'tmp_data', probesetnames ) ;
  SELECT DISTINCT probeset.stable_id AS IN1, exon.exon_id, exon.stable_id, exon.chromosome_id, exon.chromosome_name,
        exon.start, exon.end, exon.strand, exon.phase,
        exon.end_phase, exon.sequence
  FROM tmp_data
    JOIN probeset ON ( tmp_data.ids = probeset.stable_id AND probeset.array_name = arrayname )
    JOIN probemap ON ( probeset.probeset_id = probemap.probeset_id )
    JOIN hit ON ( probemap.probe_id = hit.probe_id )
    JOIN hit_exon ON ( hit.hit_id = hit_exon.hit_id )
    JOIN exon ON ( exon.exon_id = hit_exon.exon_id )
 ;
END$$


DROP PROCEDURE IF EXISTS probeset_to_est_gene$$
CREATE PROCEDURE probeset_to_est_gene( arrayname TEXT, probesetnames TEXT )
BEGIN
  DROP TEMPORARY TABLE IF EXISTS tmp_data ;
  CREATE TEMPORARY TABLE tmp_data (
    ids VARCHAR( 80 ),
    INDEX USING HASH ( ids )
  ) ENGINE=MEMORY ;
  CALL tokeniser( 'tmp_data', probesetnames ) ;
  SELECT DISTINCT probeset.stable_id AS IN1, est_gene.gene_id, est_gene.stable_id, est_gene.chromosome_id, est_gene.chromosome_name,
        est_gene.start, est_gene.end, est_gene.strand, est_gene.biotype,
        est_gene.status, est_gene.description, est_gene.synonym_id, est_gene.external_db_id,
        est_gene.db_display_name, est_gene.symbol, est_gene.symbol_description
  FROM tmp_data
    JOIN probeset ON ( tmp_data.ids = probeset.stable_id AND probeset.array_name = arrayname )
    JOIN probemap ON ( probeset.probeset_id = probemap.probeset_id )
    JOIN hit ON ( probemap.probe_id = hit.probe_id )
    JOIN hit_est_gene ON ( hit.hit_id = hit_est_gene.hit_id )
    JOIN est_gene ON ( est_gene.gene_id = hit_est_gene.gene_id )
 ;
END$$


DROP PROCEDURE IF EXISTS probeset_to_est_transcript$$
CREATE PROCEDURE probeset_to_est_transcript( arrayname TEXT, probesetnames TEXT )
BEGIN
  DROP TEMPORARY TABLE IF EXISTS tmp_data ;
  CREATE TEMPORARY TABLE tmp_data (
    ids VARCHAR( 80 ),
    INDEX USING HASH ( ids )
  ) ENGINE=MEMORY ;
  CALL tokeniser( 'tmp_data', probesetnames ) ;
  SELECT DISTINCT probeset.stable_id AS IN1, est_transcript.transcript_id, est_transcript.stable_id, est_transcript.gene_id, est_transcript.chromosome_id,
        est_transcript.chromosome_name, est_transcript.start, est_transcript.end, est_transcript.strand,
        est_transcript.biotype, est_transcript.status, est_transcript.description, est_transcript.synonym_id,
        est_transcript.external_db_id, est_transcript.db_display_name, est_transcript.symbol, est_transcript.symbol_description,
        est_transcript.translation_start, est_transcript.translation_start_exon, est_transcript.translation_end, est_transcript.translation_end_exon
  FROM tmp_data
    JOIN probeset ON ( tmp_data.ids = probeset.stable_id AND probeset.array_name = arrayname )
    JOIN probemap ON ( probeset.probeset_id = probemap.probeset_id )
    JOIN hit ON ( probemap.probe_id = hit.probe_id )
    JOIN hit_est_transcript ON ( hit.hit_id = hit_est_transcript.hit_id )
    JOIN est_transcript ON ( est_transcript.transcript_id = hit_est_transcript.transcript_id )
 ;
END$$


DROP PROCEDURE IF EXISTS probeset_to_est_exon$$
CREATE PROCEDURE probeset_to_est_exon( arrayname TEXT, probesetnames TEXT )
BEGIN
  DROP TEMPORARY TABLE IF EXISTS tmp_data ;
  CREATE TEMPORARY TABLE tmp_data (
    ids VARCHAR( 80 ),
    INDEX USING HASH ( ids )
  ) ENGINE=MEMORY ;
  CALL tokeniser( 'tmp_data', probesetnames ) ;
  SELECT DISTINCT probeset.stable_id AS IN1, est_exon.exon_id, est_exon.stable_id, est_exon.chromosome_id, est_exon.chromosome_name,
        est_exon.start, est_exon.end, est_exon.strand, est_exon.phase,
        est_exon.end_phase, est_exon.sequence
  FROM tmp_data
    JOIN probeset ON ( tmp_data.ids = probeset.stable_id AND probeset.array_name = arrayname )
    JOIN probemap ON ( probeset.probeset_id = probemap.probeset_id )
    JOIN hit ON ( probemap.probe_id = hit.probe_id )
    JOIN hit_est_exon ON ( hit.hit_id = hit_est_exon.hit_id )
    JOIN est_exon ON ( est_exon.exon_id = hit_est_exon.exon_id )
 ;
END$$


DROP PROCEDURE IF EXISTS probeset_to_probe$$
CREATE PROCEDURE probeset_to_probe( arrayname TEXT, probesetnames TEXT )
BEGIN
  DROP TEMPORARY TABLE IF EXISTS tmp_data ;
  CREATE TEMPORARY TABLE tmp_data (
    ids VARCHAR( 80 ),
    INDEX USING HASH ( ids )
  ) ENGINE=MEMORY ;
  CALL tokeniser( 'tmp_data', probesetnames ) ;
  SELECT DISTINCT probeset.stable_id AS IN1, probe.probe_id, probe.sequence, probe.probe_hit_count
  FROM tmp_data
    JOIN probeset ON ( tmp_data.ids = probeset.stable_id AND probeset.array_name = arrayname )
    JOIN probemap ON ( probeset.probeset_id = probemap.probeset_id )
    JOIN probe ON ( probe.probe_id = probemap.probe_id )
 ;
END$$


DROP PROCEDURE IF EXISTS probeset_to_hit$$
CREATE PROCEDURE probeset_to_hit( arrayname TEXT, probesetnames TEXT )
BEGIN
  DROP TEMPORARY TABLE IF EXISTS tmp_data ;
  CREATE TEMPORARY TABLE tmp_data (
    ids VARCHAR( 80 ),
    INDEX USING HASH ( ids )
  ) ENGINE=MEMORY ;
  CALL tokeniser( 'tmp_data', probesetnames ) ;
  SELECT DISTINCT probeset.stable_id AS IN1, hit.hit_id, hit.probe_id, hit.chromosome_id, hit.chromosome_name,
        hit.start, hit.end, hit.strand
  FROM tmp_data
    JOIN probeset ON ( tmp_data.ids = probeset.stable_id AND probeset.array_name = arrayname )
    JOIN probemap ON ( probeset.probeset_id = probemap.probeset_id )
    JOIN hit ON ( probemap.probe_id = hit.probe_id )
 ;
END$$


DROP PROCEDURE IF EXISTS probeset_to_prediction_transcript$$
CREATE PROCEDURE probeset_to_prediction_transcript( arrayname TEXT, probesetnames TEXT )
BEGIN
  DROP TEMPORARY TABLE IF EXISTS tmp_data ;
  CREATE TEMPORARY TABLE tmp_data (
    ids VARCHAR( 80 ),
    INDEX USING HASH ( ids )
  ) ENGINE=MEMORY ;
  CALL tokeniser( 'tmp_data', probesetnames ) ;
  SELECT DISTINCT probeset.stable_id AS IN1, prediction_transcript.transcript_id, prediction_transcript.stable_id, prediction_transcript.chromosome_id, prediction_transcript.chromosome_name,
        prediction_transcript.start, prediction_transcript.end, prediction_transcript.strand
  FROM tmp_data
    JOIN probeset ON ( tmp_data.ids = probeset.stable_id AND probeset.array_name = arrayname )
    JOIN probemap ON ( probeset.probeset_id = probemap.probeset_id )
    JOIN hit ON ( probemap.probe_id = hit.probe_id )
    JOIN hit_prediction_transcript ON ( hit.hit_id = hit_prediction_transcript.hit_id )
    JOIN prediction_transcript ON ( prediction_transcript.transcript_id = hit_prediction_transcript.transcript_id )
 ;
END$$


DROP PROCEDURE IF EXISTS probeset_to_protein$$
CREATE PROCEDURE probeset_to_protein( arrayname TEXT, probesetnames TEXT )
BEGIN
  DROP TEMPORARY TABLE IF EXISTS tmp_data ;
  CREATE TEMPORARY TABLE tmp_data (
    ids VARCHAR( 80 ),
    INDEX USING HASH ( ids )
  ) ENGINE=MEMORY ;
  CALL tokeniser( 'tmp_data', probesetnames ) ;
  SELECT DISTINCT probeset.stable_id AS IN1, protein.protein_id, protein.stable_id, protein.gene_id, protein.transcript_id,
        protein.chromosome_id, protein.chromosome_name, protein.start, protein.end,
        protein.strand
  FROM tmp_data
    JOIN probeset ON ( tmp_data.ids = probeset.stable_id AND probeset.array_name = arrayname )
    JOIN probemap ON ( probeset.probeset_id = probemap.probeset_id )
    JOIN hit ON ( probemap.probe_id = hit.probe_id )
    JOIN hit_protein ON ( hit_protein.hit_id = hit.hit_id )
    JOIN protein ON ( hit_protein.protein_id = protein.protein_id )
 ;
END$$


DROP PROCEDURE IF EXISTS probeset_to_domain$$
CREATE PROCEDURE probeset_to_domain( arrayname TEXT, probesetnames TEXT )
BEGIN
  DROP TEMPORARY TABLE IF EXISTS tmp_data ;
  CREATE TEMPORARY TABLE tmp_data (
    ids VARCHAR( 80 ),
    INDEX USING HASH ( ids )
  ) ENGINE=MEMORY ;
  CALL tokeniser( 'tmp_data', probesetnames ) ;
  SELECT DISTINCT probeset.stable_id AS IN1, domain.hit_id, domain.stable_id, domain.symbol, domain.description,
        domain.model_length, domain.type, domain.protein_id, domain.seq_start,
        domain.seq_end, domain.hmm_start, domain.hmm_end, domain.bit_score,
        domain.evalue, domain.chromosome_id, domain.chromosome_name, domain.start,
        domain.end, domain.strand
  FROM tmp_data
    JOIN probeset ON ( tmp_data.ids = probeset.stable_id AND probeset.array_name = arrayname )
    JOIN probemap ON ( probeset.probeset_id = probemap.probeset_id )
    JOIN hit ON ( probemap.probe_id = hit.probe_id )
    JOIN hit_domain ON ( hit_domain.hit_id = hit.hit_id )
    JOIN domain ON ( hit_domain.domain_id = domain.hit_id )
 ;
END$$


DROP PROCEDURE IF EXISTS probes_in_range_quick$$
CREATE PROCEDURE probes_in_range_quick( arrayname TEXT, chr VARCHAR(40), qstart INTEGER(10), qstop INTEGER(10), qstrand TINYINT(2) )
BEGIN
  SELECT DISTINCT probe.probe_id, probe.sequence, probe.probe_hit_count, hit.hit_id,
        hit.probe_id, hit.chromosome_id, hit.chromosome_name, hit.start,
        hit.end, hit.strand
  FROM probe
    JOIN hit ON ( probe.probe_id = hit.probe_id )
    JOIN probemap ON ( probe.probe_id = probemap.probe_id )
    JOIN probeset ON ( probemap.probeset_id = probeset.probeset_id )
  WHERE ( probeset.array_name = arrayname ) AND ( chromosome_name = chr ) AND ( start >= qstart AND start < qstop ) AND ( qstrand = 0 OR strand = qstrand )
  ORDER BY start ASC ;
END$$


DROP PROCEDURE IF EXISTS all_probes$$
CREATE PROCEDURE all_probes( arrayname VARCHAR(40) )
BEGIN
  SELECT probe.probe_id, probe.sequence, probe.probe_hit_count
    FROM probe
      JOIN probemap USING( probe_id ) JOIN probeset USING( probeset_id )
    WHERE array_name = arrayname
    ORDER BY probe_id ASC ;
END$$

DROP PROCEDURE IF EXISTS probe_details$$
CREATE PROCEDURE probe_details( arrayname VARCHAR(40), ids TEXT )
BEGIN
  DROP TEMPORARY TABLE IF EXISTS tmp_data ;
  CREATE TEMPORARY TABLE tmp_data (
    ids VARCHAR( 80 ),
    INDEX USING HASH ( ids )
  ) ENGINE=MEMORY ;
  CALL tokeniser( 'tmp_data', ids ) ;
  SELECT tmp_data.ids AS IN1, probe.probe_id, probe.sequence, probe.probe_hit_count
    FROM tmp_data
      JOIN probe ON ( probe.sequence = tmp_data.ids )
      JOIN probemap USING( probe_id ) JOIN probeset USING( probeset_id )
    WHERE array_name = arrayname ;
END$$


DROP PROCEDURE IF EXISTS probe_to_hit$$
CREATE PROCEDURE probe_to_hit( arrayname TEXT, sequences TEXT )
BEGIN
  DROP TEMPORARY TABLE IF EXISTS tmp_data ;
  CREATE TEMPORARY TABLE tmp_data (
    ids VARCHAR( 80 ),
    INDEX USING HASH ( ids )
  ) ENGINE=MEMORY ;
  CALL tokeniser( 'tmp_data', sequences ) ;
  SELECT DISTINCT probe.sequence AS IN1, hit.hit_id, hit.probe_id, hit.chromosome_id, hit.chromosome_name,
        hit.start, hit.end, hit.strand
  FROM tmp_data
    JOIN probe ON ( tmp_data.ids = probe.sequence )
    JOIN hit ON ( probe.probe_id = hit.probe_id )
    JOIN probemap ON ( probe.probe_id = probemap.probe_id )
    JOIN probeset ON ( probemap.probeset_id = probeset.probeset_id AND probeset.array_name = arrayname )
 ;
END$$


DROP PROCEDURE IF EXISTS probe_to_probeset$$
CREATE PROCEDURE probe_to_probeset( arrayname TEXT, sequences TEXT )
BEGIN
  DROP TEMPORARY TABLE IF EXISTS tmp_data ;
  CREATE TEMPORARY TABLE tmp_data (
    ids VARCHAR( 80 ),
    INDEX USING HASH ( ids )
  ) ENGINE=MEMORY ;
  CALL tokeniser( 'tmp_data', sequences ) ;
  SELECT DISTINCT probe.sequence AS IN1, probeset.probeset_id, probeset.stable_id, probeset.array_id, probeset.array_name,
        probeset.probe_count, probeset.hit_score, probeset.gene_score, probeset.transcript_score,
        probeset.exon_score, probeset.est_gene_score, probeset.est_transcript_score, probeset.est_exon_score,
        probeset.prediction_transcript_score, probeset.prediction_exon_score, probeset.protein_score, probeset.domain_score
  FROM tmp_data
    JOIN probe ON ( tmp_data.ids = probe.sequence )
    JOIN probemap ON ( probe.probe_id = probemap.probe_id )
    JOIN probeset ON ( probemap.probeset_id = probeset.probeset_id AND probeset.array_name = arrayname )
 ;
END$$


DROP PROCEDURE IF EXISTS proteins_in_range$$
CREATE PROCEDURE proteins_in_range( chr VARCHAR(40), qstart INTEGER(10), qstop INTEGER(10), qstrand TINYINT(2) )
BEGIN
  SELECT DISTINCT protein.protein_id, protein.stable_id, protein.gene_id, protein.transcript_id,
        protein.chromosome_id, protein.chromosome_name, protein.start, protein.end,
        protein.strand
  FROM protein
  WHERE ( chromosome_name = chr ) AND ( start <= qstop ) AND ( end >= qstart ) AND ( qstrand = 0 OR strand = qstrand )
  ORDER BY start ASC ;
END$$


DROP PROCEDURE IF EXISTS all_proteins$$
CREATE PROCEDURE all_proteins(  )
BEGIN
  SELECT protein.protein_id, protein.stable_id, protein.gene_id, protein.transcript_id, 
       protein.chromosome_id, protein.chromosome_name, protein.start, protein.end, 
       protein.strand
    FROM protein
    ORDER BY protein_id ASC ;
END$$

DROP PROCEDURE IF EXISTS protein_details$$
CREATE PROCEDURE protein_details( ids TEXT )
BEGIN
  DROP TEMPORARY TABLE IF EXISTS tmp_data ;
  CREATE TEMPORARY TABLE tmp_data (
    ids VARCHAR( 80 ),
    INDEX USING HASH ( ids )
  ) ENGINE=MEMORY ;
  CALL tokeniser( 'tmp_data', ids ) ;
  SELECT tmp_data.ids AS IN1, protein.protein_id, protein.stable_id, protein.gene_id, protein.transcript_id, 
       protein.chromosome_id, protein.chromosome_name, protein.start, protein.end, 
       protein.strand
    FROM tmp_data
      JOIN protein ON ( protein.stable_id = tmp_data.ids ) ;
END$$


DROP PROCEDURE IF EXISTS protein_to_domain$$
CREATE PROCEDURE protein_to_domain( proteinids TEXT )
BEGIN
  DROP TEMPORARY TABLE IF EXISTS tmp_data ;
  CREATE TEMPORARY TABLE tmp_data (
    ids VARCHAR( 80 ),
    INDEX USING HASH ( ids )
  ) ENGINE=MEMORY ;
  CALL tokeniser( 'tmp_data', proteinids ) ;
  SELECT DISTINCT protein.stable_id AS IN1, domain.hit_id, domain.stable_id, domain.symbol, domain.description,
        domain.model_length, domain.type, domain.protein_id, domain.seq_start,
        domain.seq_end, domain.hmm_start, domain.hmm_end, domain.bit_score,
        domain.evalue, domain.chromosome_id, domain.chromosome_name, domain.start,
        domain.end, domain.strand
  FROM tmp_data
    JOIN protein ON ( tmp_data.ids = protein.stable_id )
    JOIN domain ON ( domain.protein_id = protein.protein_id )
 ;
END$$


DROP PROCEDURE IF EXISTS protein_to_gene$$
CREATE PROCEDURE protein_to_gene( proteinids TEXT )
BEGIN
  DROP TEMPORARY TABLE IF EXISTS tmp_data ;
  CREATE TEMPORARY TABLE tmp_data (
    ids VARCHAR( 80 ),
    INDEX USING HASH ( ids )
  ) ENGINE=MEMORY ;
  CALL tokeniser( 'tmp_data', proteinids ) ;
  SELECT DISTINCT protein.stable_id AS IN1, gene.gene_id, gene.stable_id, gene.chromosome_id, gene.chromosome_name,
        gene.start, gene.end, gene.strand, gene.biotype,
        gene.status, gene.description, gene.synonym_id, gene.external_db_id,
        gene.db_display_name, gene.symbol, gene.symbol_description, gene.analysis_name
  FROM tmp_data
    JOIN protein ON ( tmp_data.ids = protein.stable_id )
    JOIN gene ON ( protein.gene_id = gene.gene_id )
 ;
END$$


DROP PROCEDURE IF EXISTS protein_to_transcript$$
CREATE PROCEDURE protein_to_transcript( proteinids TEXT )
BEGIN
  DROP TEMPORARY TABLE IF EXISTS tmp_data ;
  CREATE TEMPORARY TABLE tmp_data (
    ids VARCHAR( 80 ),
    INDEX USING HASH ( ids )
  ) ENGINE=MEMORY ;
  CALL tokeniser( 'tmp_data', proteinids ) ;
  SELECT DISTINCT protein.stable_id AS IN1, transcript.transcript_id, transcript.stable_id, transcript.gene_id, transcript.chromosome_id,
        transcript.chromosome_name, transcript.start, transcript.end, transcript.strand,
        transcript.biotype, transcript.status, transcript.description, transcript.synonym_id,
        transcript.external_db_id, transcript.db_display_name, transcript.symbol, transcript.symbol_description,
        transcript.translation_start, transcript.translation_start_exon, transcript.translation_end, transcript.translation_end_exon,
        transcript.analysis_name
  FROM tmp_data
    JOIN protein ON ( tmp_data.ids = protein.stable_id )
    JOIN transcript ON ( protein.transcript_id = transcript.transcript_id )
 ;
END$$


DROP PROCEDURE IF EXISTS protein_to_probeset$$
CREATE PROCEDURE protein_to_probeset( arrayname TEXT, proteinids TEXT )
BEGIN
  DROP TEMPORARY TABLE IF EXISTS tmp_data ;
  CREATE TEMPORARY TABLE tmp_data (
    ids VARCHAR( 80 ),
    INDEX USING HASH ( ids )
  ) ENGINE=MEMORY ;
  CALL tokeniser( 'tmp_data', proteinids ) ;
  SELECT DISTINCT protein.stable_id AS IN1, probeset.probeset_id, probeset.stable_id, probeset.array_id, probeset.array_name,
        probeset.probe_count, probeset.hit_score, probeset.gene_score, probeset.transcript_score,
        probeset.exon_score, probeset.est_gene_score, probeset.est_transcript_score, probeset.est_exon_score,
        probeset.prediction_transcript_score, probeset.prediction_exon_score, probeset.protein_score, probeset.domain_score
  FROM tmp_data
    JOIN protein ON ( tmp_data.ids = protein.stable_id )
    JOIN hit_protein ON ( protein.protein_id = hit_protein.protein_id )
    JOIN hit ON ( hit_protein.hit_id = hit.hit_id )
    JOIN probemap ON ( hit.probe_id = probemap.probe_id )
    JOIN probeset ON ( probemap.probeset_id = probeset.probeset_id AND probeset.array_name = arrayname )
 ;
END$$


DROP PROCEDURE IF EXISTS domains_in_range$$
CREATE PROCEDURE domains_in_range( chr VARCHAR(40), qstart INTEGER(10), qstop INTEGER(10), qstrand TINYINT(2) )
BEGIN
  SELECT DISTINCT domain.hit_id, domain.stable_id, domain.symbol, domain.description,
        domain.model_length, domain.type, domain.protein_id, domain.seq_start,
        domain.seq_end, domain.hmm_start, domain.hmm_end, domain.bit_score,
        domain.evalue, domain.chromosome_id, domain.chromosome_name, domain.start,
        domain.end, domain.strand
  FROM domain
  WHERE ( chromosome_name = chr ) AND ( start <= qstop ) AND ( end >= qstart ) AND ( qstrand = 0 OR strand = qstrand )
  ORDER BY start ASC ;
END$$


DROP PROCEDURE IF EXISTS all_domains$$
CREATE PROCEDURE all_domains(  )
BEGIN
  SELECT domain.hit_id, domain.stable_id, domain.symbol, domain.description, 
       domain.model_length, domain.type, domain.protein_id, domain.seq_start, 
       domain.seq_end, domain.hmm_start, domain.hmm_end, domain.bit_score, 
       domain.evalue, domain.chromosome_id, domain.chromosome_name, domain.start, 
       domain.end, domain.strand
    FROM domain
    ORDER BY hit_id ASC ;
END$$

DROP PROCEDURE IF EXISTS domain_details$$
CREATE PROCEDURE domain_details( ids TEXT )
BEGIN
  DROP TEMPORARY TABLE IF EXISTS tmp_data ;
  CREATE TEMPORARY TABLE tmp_data (
    ids VARCHAR( 80 ),
    INDEX USING HASH ( ids )
  ) ENGINE=MEMORY ;
  CALL tokeniser( 'tmp_data', ids ) ;
  SELECT tmp_data.ids AS IN1, domain.hit_id, domain.stable_id, domain.symbol, domain.description, 
       domain.model_length, domain.type, domain.protein_id, domain.seq_start, 
       domain.seq_end, domain.hmm_start, domain.hmm_end, domain.bit_score, 
       domain.evalue, domain.chromosome_id, domain.chromosome_name, domain.start, 
       domain.end, domain.strand
    FROM tmp_data
      JOIN domain ON ( domain.stable_id = tmp_data.ids ) ;
END$$


DROP PROCEDURE IF EXISTS domain_to_protein$$
CREATE PROCEDURE domain_to_protein( domainids TEXT )
BEGIN
  DROP TEMPORARY TABLE IF EXISTS tmp_data ;
  CREATE TEMPORARY TABLE tmp_data (
    ids VARCHAR( 80 ),
    INDEX USING HASH ( ids )
  ) ENGINE=MEMORY ;
  CALL tokeniser( 'tmp_data', domainids ) ;
  SELECT DISTINCT domain.stable_id AS IN1, protein.protein_id, protein.stable_id, protein.gene_id, protein.transcript_id,
        protein.chromosome_id, protein.chromosome_name, protein.start, protein.end,
        protein.strand
  FROM tmp_data
    JOIN domain ON ( tmp_data.ids = domain.stable_id )
    JOIN protein ON ( domain.protein_id = protein.protein_id )
 ;
END$$


DROP PROCEDURE IF EXISTS domain_to_gene$$
CREATE PROCEDURE domain_to_gene( domainids TEXT )
BEGIN
  DROP TEMPORARY TABLE IF EXISTS tmp_data ;
  CREATE TEMPORARY TABLE tmp_data (
    ids VARCHAR( 80 ),
    INDEX USING HASH ( ids )
  ) ENGINE=MEMORY ;
  CALL tokeniser( 'tmp_data', domainids ) ;
  SELECT DISTINCT domain.stable_id AS IN1, gene.gene_id, gene.stable_id, gene.chromosome_id, gene.chromosome_name,
        gene.start, gene.end, gene.strand, gene.biotype,
        gene.status, gene.description, gene.synonym_id, gene.external_db_id,
        gene.db_display_name, gene.symbol, gene.symbol_description, gene.analysis_name
  FROM tmp_data
    JOIN domain ON ( tmp_data.ids = domain.stable_id )
    JOIN protein ON ( domain.protein_id = protein.protein_id )
    JOIN gene ON ( protein.gene_id = gene.gene_id )
 ;
END$$


DROP PROCEDURE IF EXISTS domain_to_transcript$$
CREATE PROCEDURE domain_to_transcript( domainids TEXT )
BEGIN
  DROP TEMPORARY TABLE IF EXISTS tmp_data ;
  CREATE TEMPORARY TABLE tmp_data (
    ids VARCHAR( 80 ),
    INDEX USING HASH ( ids )
  ) ENGINE=MEMORY ;
  CALL tokeniser( 'tmp_data', domainids ) ;
  SELECT DISTINCT domain.stable_id AS IN1, transcript.transcript_id, transcript.stable_id, transcript.gene_id, transcript.chromosome_id,
        transcript.chromosome_name, transcript.start, transcript.end, transcript.strand,
        transcript.biotype, transcript.status, transcript.description, transcript.synonym_id,
        transcript.external_db_id, transcript.db_display_name, transcript.symbol, transcript.symbol_description,
        transcript.translation_start, transcript.translation_start_exon, transcript.translation_end, transcript.translation_end_exon,
        transcript.analysis_name
  FROM tmp_data
    JOIN domain ON ( tmp_data.ids = domain.stable_id )
    JOIN protein ON ( domain.protein_id = protein.protein_id )
    JOIN transcript ON ( protein.transcript_id = transcript.transcript_id )
 ;
END$$


DROP PROCEDURE IF EXISTS domain_to_probeset$$
CREATE PROCEDURE domain_to_probeset( arrayname TEXT, domainids TEXT )
BEGIN
  DROP TEMPORARY TABLE IF EXISTS tmp_data ;
  CREATE TEMPORARY TABLE tmp_data (
    ids VARCHAR( 80 ),
    INDEX USING HASH ( ids )
  ) ENGINE=MEMORY ;
  CALL tokeniser( 'tmp_data', domainids ) ;
  SELECT DISTINCT domain.stable_id AS IN1, probeset.probeset_id, probeset.stable_id, probeset.array_id, probeset.array_name,
        probeset.probe_count, probeset.hit_score, probeset.gene_score, probeset.transcript_score,
        probeset.exon_score, probeset.est_gene_score, probeset.est_transcript_score, probeset.est_exon_score,
        probeset.prediction_transcript_score, probeset.prediction_exon_score, probeset.protein_score, probeset.domain_score
  FROM tmp_data
    JOIN domain ON ( tmp_data.ids = domain.stable_id )
    JOIN hit_domain ON ( domain.hit_id = hit_domain.domain_id )
    JOIN hit ON ( hit_domain.hit_id = hit.hit_id )
    JOIN probemap ON ( hit.probe_id = probemap.probe_id )
    JOIN probeset ON ( probemap.probeset_id = probeset.probeset_id AND probeset.array_name = arrayname )
 ;
END$$


DROP PROCEDURE IF EXISTS all_chromosomes$$
CREATE PROCEDURE all_chromosomes(  )
BEGIN
  SELECT chromosome.chromosome_id, chromosome.name, chromosome.length
    FROM chromosome
    ORDER BY chromosome_id ASC ;
END$$

DROP PROCEDURE IF EXISTS chromosome_details$$
CREATE PROCEDURE chromosome_details( ids TEXT )
BEGIN
  DROP TEMPORARY TABLE IF EXISTS tmp_data ;
  CREATE TEMPORARY TABLE tmp_data (
    ids VARCHAR( 80 ),
    INDEX USING HASH ( ids )
  ) ENGINE=MEMORY ;
  CALL tokeniser( 'tmp_data', ids ) ;
  SELECT tmp_data.ids AS IN1, chromosome.chromosome_id, chromosome.name, chromosome.length
    FROM tmp_data
      JOIN chromosome ON ( chromosome.name = tmp_data.ids ) ;
END$$


DROP PROCEDURE IF EXISTS genes_in_range$$
CREATE PROCEDURE genes_in_range( chr VARCHAR(40), qstart INTEGER(10), qstop INTEGER(10), qstrand TINYINT(2) )
BEGIN
  SELECT DISTINCT gene.gene_id, gene.stable_id, gene.chromosome_id, gene.chromosome_name,
        gene.start, gene.end, gene.strand, gene.biotype,
        gene.status, gene.description, gene.synonym_id, gene.external_db_id,
        gene.db_display_name, gene.symbol, gene.symbol_description, gene.analysis_name
  FROM gene
  WHERE ( chromosome_name = chr ) AND ( start <= qstop ) AND ( end >= qstart ) AND ( qstrand = 0 OR strand = qstrand )
  ORDER BY start ASC ;
END$$


DROP PROCEDURE IF EXISTS all_genes$$
CREATE PROCEDURE all_genes(  )
BEGIN
  SELECT gene.gene_id, gene.stable_id, gene.chromosome_id, gene.chromosome_name, 
       gene.start, gene.end, gene.strand, gene.biotype, 
       gene.status, gene.description, gene.synonym_id, gene.external_db_id, 
       gene.db_display_name, gene.symbol, gene.symbol_description, gene.analysis_name
    FROM gene
    ORDER BY gene_id ASC ;
END$$

DROP PROCEDURE IF EXISTS gene_details$$
CREATE PROCEDURE gene_details( ids TEXT )
BEGIN
  DROP TEMPORARY TABLE IF EXISTS tmp_data ;
  CREATE TEMPORARY TABLE tmp_data (
    ids VARCHAR( 80 ),
    INDEX USING HASH ( ids )
  ) ENGINE=MEMORY ;
  CALL tokeniser( 'tmp_data', ids ) ;
  SELECT tmp_data.ids AS IN1, gene.gene_id, gene.stable_id, gene.chromosome_id, gene.chromosome_name, 
       gene.start, gene.end, gene.strand, gene.biotype, 
       gene.status, gene.description, gene.synonym_id, gene.external_db_id, 
       gene.db_display_name, gene.symbol, gene.symbol_description, gene.analysis_name
    FROM tmp_data
      JOIN gene ON ( gene.stable_id = tmp_data.ids ) ;
END$$


DROP PROCEDURE IF EXISTS gene_to_transcript$$
CREATE PROCEDURE gene_to_transcript( geneids TEXT )
BEGIN
  DROP TEMPORARY TABLE IF EXISTS tmp_data ;
  CREATE TEMPORARY TABLE tmp_data (
    ids VARCHAR( 80 ),
    INDEX USING HASH ( ids )
  ) ENGINE=MEMORY ;
  CALL tokeniser( 'tmp_data', geneids ) ;
  SELECT DISTINCT gene.stable_id AS IN1, transcript.transcript_id, transcript.stable_id, transcript.gene_id, transcript.chromosome_id,
        transcript.chromosome_name, transcript.start, transcript.end, transcript.strand,
        transcript.biotype, transcript.status, transcript.description, transcript.synonym_id,
        transcript.external_db_id, transcript.db_display_name, transcript.symbol, transcript.symbol_description,
        transcript.translation_start, transcript.translation_start_exon, transcript.translation_end, transcript.translation_end_exon,
        transcript.analysis_name
  FROM tmp_data
    JOIN gene ON ( tmp_data.ids = gene.stable_id )
    JOIN transcript ON ( gene.gene_id = transcript.gene_id )
 ;
END$$


DROP PROCEDURE IF EXISTS gene_to_exon$$
CREATE PROCEDURE gene_to_exon( geneids TEXT )
BEGIN
  DROP TEMPORARY TABLE IF EXISTS tmp_data ;
  CREATE TEMPORARY TABLE tmp_data (
    ids VARCHAR( 80 ),
    INDEX USING HASH ( ids )
  ) ENGINE=MEMORY ;
  CALL tokeniser( 'tmp_data', geneids ) ;
  SELECT DISTINCT gene.stable_id AS IN1, exon.exon_id, exon.stable_id, exon.chromosome_id, exon.chromosome_name,
        exon.start, exon.end, exon.strand, exon.phase,
        exon.end_phase, exon.sequence
  FROM tmp_data
    JOIN gene ON ( tmp_data.ids = gene.stable_id )
    JOIN transcript ON ( gene.gene_id = transcript.gene_id )
    JOIN exon_transcript ON ( transcript.transcript_id = exon_transcript.transcript_id )
    JOIN exon ON ( exon_transcript.exon_id = exon.exon_id )
 ;
END$$


DROP PROCEDURE IF EXISTS gene_to_exon_probeset$$
CREATE PROCEDURE gene_to_exon_probeset( arrayname TEXT, geneids TEXT )
BEGIN
  DROP TEMPORARY TABLE IF EXISTS tmp_data ;
  CREATE TEMPORARY TABLE tmp_data (
    ids VARCHAR( 80 ),
    INDEX USING HASH ( ids )
  ) ENGINE=MEMORY ;
  CALL tokeniser( 'tmp_data', geneids ) ;
  SELECT DISTINCT gene.stable_id AS IN1, exon.stable_id as exon, probeset.stable_id as probeset, COUNT( distinct probemap.probe_id ) AS num_probes, probe_count
  FROM tmp_data
    JOIN gene ON ( tmp_data.ids = gene.stable_id )
    JOIN transcript ON ( gene.gene_id = transcript.gene_id )
    JOIN exon_transcript ON ( transcript.transcript_id = exon_transcript.transcript_id )
    JOIN exon ON ( exon_transcript.exon_id = exon.exon_id )
    JOIN hit_exon ON ( exon.exon_id = hit_exon.exon_id )
    JOIN hit ON ( hit_exon.hit_id = hit.hit_id )
    JOIN probemap ON ( hit.probe_id = probemap.probe_id )
    JOIN probeset ON ( probemap.probeset_id = probeset.probeset_id AND probeset.array_name = arrayname )
GROUP BY IN1, exon, probeset, probe_count ORDER BY num_probes DESC, exon, probeset ;
END$$


DROP PROCEDURE IF EXISTS gene_to_probeset$$
CREATE PROCEDURE gene_to_probeset( arrayname TEXT, geneids TEXT )
BEGIN
  DROP TEMPORARY TABLE IF EXISTS tmp_data ;
  CREATE TEMPORARY TABLE tmp_data (
    ids VARCHAR( 80 ),
    INDEX USING HASH ( ids )
  ) ENGINE=MEMORY ;
  CALL tokeniser( 'tmp_data', geneids ) ;
  SELECT DISTINCT gene.stable_id AS IN1, probeset.probeset_id, probeset.stable_id, probeset.array_id, probeset.array_name,
        probeset.probe_count, probeset.hit_score, probeset.gene_score, probeset.transcript_score,
        probeset.exon_score, probeset.est_gene_score, probeset.est_transcript_score, probeset.est_exon_score,
        probeset.prediction_transcript_score, probeset.prediction_exon_score, probeset.protein_score, probeset.domain_score
  FROM tmp_data
    JOIN gene ON ( tmp_data.ids = gene.stable_id )
    JOIN hit_gene ON ( gene.gene_id = hit_gene.gene_id )
    JOIN hit ON ( hit_gene.hit_id = hit.hit_id )
    JOIN probemap ON ( hit.probe_id = probemap.probe_id )
    JOIN probeset ON ( probemap.probeset_id = probeset.probeset_id AND probeset.array_name = arrayname )
 ;
END$$


DROP PROCEDURE IF EXISTS gene_to_synonym$$
CREATE PROCEDURE gene_to_synonym( geneids TEXT )
BEGIN
  DROP TEMPORARY TABLE IF EXISTS tmp_data ;
  CREATE TEMPORARY TABLE tmp_data (
    ids VARCHAR( 80 ),
    INDEX USING HASH ( ids )
  ) ENGINE=MEMORY ;
  CALL tokeniser( 'tmp_data', geneids ) ;
  SELECT DISTINCT gene.stable_id AS IN1, synonym.synonym_id, synonym.synonym
  FROM tmp_data
    JOIN gene ON ( tmp_data.ids = gene.stable_id )
    JOIN synonym ON ( gene.synonym_id = synonym.synonym_id )
 ;
END$$


DROP PROCEDURE IF EXISTS gene_to_protein$$
CREATE PROCEDURE gene_to_protein( geneids TEXT )
BEGIN
  DROP TEMPORARY TABLE IF EXISTS tmp_data ;
  CREATE TEMPORARY TABLE tmp_data (
    ids VARCHAR( 80 ),
    INDEX USING HASH ( ids )
  ) ENGINE=MEMORY ;
  CALL tokeniser( 'tmp_data', geneids ) ;
  SELECT DISTINCT gene.stable_id AS IN1, protein.protein_id, protein.stable_id, protein.gene_id, protein.transcript_id,
        protein.chromosome_id, protein.chromosome_name, protein.start, protein.end,
        protein.strand
  FROM tmp_data
    JOIN gene ON ( tmp_data.ids = gene.stable_id )
    JOIN protein ON ( protein.gene_id = gene.gene_id )
 ;
END$$


DROP PROCEDURE IF EXISTS gene_to_domain$$
CREATE PROCEDURE gene_to_domain( geneids TEXT )
BEGIN
  DROP TEMPORARY TABLE IF EXISTS tmp_data ;
  CREATE TEMPORARY TABLE tmp_data (
    ids VARCHAR( 80 ),
    INDEX USING HASH ( ids )
  ) ENGINE=MEMORY ;
  CALL tokeniser( 'tmp_data', geneids ) ;
  SELECT DISTINCT gene.stable_id AS IN1, domain.hit_id, domain.stable_id, domain.symbol, domain.description,
        domain.model_length, domain.type, domain.protein_id, domain.seq_start,
        domain.seq_end, domain.hmm_start, domain.hmm_end, domain.bit_score,
        domain.evalue, domain.chromosome_id, domain.chromosome_name, domain.start,
        domain.end, domain.strand
  FROM tmp_data
    JOIN gene ON ( tmp_data.ids = gene.stable_id )
    JOIN protein ON ( protein.gene_id = gene.gene_id )
    JOIN domain ON ( domain.protein_id = protein.protein_id )
 ;
END$$


DROP PROCEDURE IF EXISTS transcripts_in_range$$
CREATE PROCEDURE transcripts_in_range( chr VARCHAR(40), qstart INTEGER(10), qstop INTEGER(10), qstrand TINYINT(2) )
BEGIN
  SELECT DISTINCT transcript.transcript_id, transcript.stable_id, transcript.gene_id, transcript.chromosome_id,
        transcript.chromosome_name, transcript.start, transcript.end, transcript.strand,
        transcript.biotype, transcript.status, transcript.description, transcript.synonym_id,
        transcript.external_db_id, transcript.db_display_name, transcript.symbol, transcript.symbol_description,
        transcript.translation_start, transcript.translation_start_exon, transcript.translation_end, transcript.translation_end_exon,
        transcript.analysis_name
  FROM transcript
  WHERE ( chromosome_name = chr ) AND ( start <= qstop ) AND ( end >= qstart ) AND ( qstrand = 0 OR strand = qstrand )
  ORDER BY start ASC ;
END$$


DROP PROCEDURE IF EXISTS all_transcripts$$
CREATE PROCEDURE all_transcripts(  )
BEGIN
  SELECT transcript.transcript_id, transcript.stable_id, transcript.gene_id, transcript.chromosome_id, 
       transcript.chromosome_name, transcript.start, transcript.end, transcript.strand, 
       transcript.biotype, transcript.status, transcript.description, transcript.synonym_id, 
       transcript.external_db_id, transcript.db_display_name, transcript.symbol, transcript.symbol_description, 
       transcript.translation_start, transcript.translation_start_exon, transcript.translation_end, transcript.translation_end_exon, 
       transcript.analysis_name
    FROM transcript
    ORDER BY transcript_id ASC ;
END$$

DROP PROCEDURE IF EXISTS transcript_details$$
CREATE PROCEDURE transcript_details( ids TEXT )
BEGIN
  DROP TEMPORARY TABLE IF EXISTS tmp_data ;
  CREATE TEMPORARY TABLE tmp_data (
    ids VARCHAR( 80 ),
    INDEX USING HASH ( ids )
  ) ENGINE=MEMORY ;
  CALL tokeniser( 'tmp_data', ids ) ;
  SELECT tmp_data.ids AS IN1, transcript.transcript_id, transcript.stable_id, transcript.gene_id, transcript.chromosome_id, 
       transcript.chromosome_name, transcript.start, transcript.end, transcript.strand, 
       transcript.biotype, transcript.status, transcript.description, transcript.synonym_id, 
       transcript.external_db_id, transcript.db_display_name, transcript.symbol, transcript.symbol_description, 
       transcript.translation_start, transcript.translation_start_exon, transcript.translation_end, transcript.translation_end_exon, 
       transcript.analysis_name
    FROM tmp_data
      JOIN transcript ON ( transcript.stable_id = tmp_data.ids ) ;
END$$


DROP PROCEDURE IF EXISTS transcript_to_gene$$
CREATE PROCEDURE transcript_to_gene( transcriptids TEXT )
BEGIN
  DROP TEMPORARY TABLE IF EXISTS tmp_data ;
  CREATE TEMPORARY TABLE tmp_data (
    ids VARCHAR( 80 ),
    INDEX USING HASH ( ids )
  ) ENGINE=MEMORY ;
  CALL tokeniser( 'tmp_data', transcriptids ) ;
  SELECT DISTINCT transcript.stable_id AS IN1, gene.gene_id, gene.stable_id, gene.chromosome_id, gene.chromosome_name,
        gene.start, gene.end, gene.strand, gene.biotype,
        gene.status, gene.description, gene.synonym_id, gene.external_db_id,
        gene.db_display_name, gene.symbol, gene.symbol_description, gene.analysis_name
  FROM tmp_data
    JOIN transcript ON ( tmp_data.ids = transcript.stable_id )
    JOIN gene ON ( gene.gene_id = transcript.gene_id )
 ;
END$$


DROP PROCEDURE IF EXISTS transcript_to_exon$$
CREATE PROCEDURE transcript_to_exon( transcriptids TEXT )
BEGIN
  DROP TEMPORARY TABLE IF EXISTS tmp_data ;
  CREATE TEMPORARY TABLE tmp_data (
    ids VARCHAR( 80 ),
    INDEX USING HASH ( ids )
  ) ENGINE=MEMORY ;
  CALL tokeniser( 'tmp_data', transcriptids ) ;
  SELECT DISTINCT transcript.stable_id AS IN1, exon.exon_id, exon.stable_id, exon.chromosome_id, exon.chromosome_name,
        exon.start, exon.end, exon.strand, exon.phase,
        exon.end_phase, exon.sequence
  FROM tmp_data
    JOIN transcript ON ( tmp_data.ids = transcript.stable_id )
    JOIN exon_transcript ON ( transcript.transcript_id = exon_transcript.transcript_id )
    JOIN exon ON ( exon_transcript.exon_id = exon.exon_id )
 ;
END$$


DROP PROCEDURE IF EXISTS transcript_to_exon_probeset$$
CREATE PROCEDURE transcript_to_exon_probeset( arrayname TEXT, transcriptids TEXT )
BEGIN
  DROP TEMPORARY TABLE IF EXISTS tmp_data ;
  CREATE TEMPORARY TABLE tmp_data (
    ids VARCHAR( 80 ),
    INDEX USING HASH ( ids )
  ) ENGINE=MEMORY ;
  CALL tokeniser( 'tmp_data', transcriptids ) ;
  SELECT DISTINCT transcript.stable_id AS IN1, exon.stable_id as exon, probeset.stable_id as probeset, COUNT( distinct probemap.probe_id ) AS num_probes, probe_count
  FROM tmp_data
    JOIN transcript ON ( tmp_data.ids = transcript.stable_id )
    JOIN exon_transcript ON ( transcript.transcript_id = exon_transcript.transcript_id )
    JOIN exon ON ( exon_transcript.exon_id = exon.exon_id )
    JOIN hit_exon ON ( exon.exon_id = hit_exon.exon_id )
    JOIN hit ON ( hit_exon.hit_id = hit.hit_id )
    JOIN probemap ON ( hit.probe_id = probemap.probe_id )
    JOIN probeset ON ( probemap.probeset_id = probeset.probeset_id AND probeset.array_name = arrayname )
GROUP BY IN1, exon, probeset, probe_count ORDER BY num_probes DESC, exon, probeset ;
END$$


DROP PROCEDURE IF EXISTS transcript_to_probeset$$
CREATE PROCEDURE transcript_to_probeset( arrayname TEXT, transcriptids TEXT )
BEGIN
  DROP TEMPORARY TABLE IF EXISTS tmp_data ;
  CREATE TEMPORARY TABLE tmp_data (
    ids VARCHAR( 80 ),
    INDEX USING HASH ( ids )
  ) ENGINE=MEMORY ;
  CALL tokeniser( 'tmp_data', transcriptids ) ;
  SELECT DISTINCT transcript.stable_id AS IN1, probeset.probeset_id, probeset.stable_id, probeset.array_id, probeset.array_name,
        probeset.probe_count, probeset.hit_score, probeset.gene_score, probeset.transcript_score,
        probeset.exon_score, probeset.est_gene_score, probeset.est_transcript_score, probeset.est_exon_score,
        probeset.prediction_transcript_score, probeset.prediction_exon_score, probeset.protein_score, probeset.domain_score
  FROM tmp_data
    JOIN transcript ON ( tmp_data.ids = transcript.stable_id )
    JOIN hit_transcript ON ( transcript.transcript_id = hit_transcript.transcript_id )
    JOIN hit ON ( hit_transcript.hit_id = hit.hit_id )
    JOIN probemap ON ( hit.probe_id = probemap.probe_id )
    JOIN probeset ON ( probemap.probeset_id = probeset.probeset_id AND probeset.array_name = arrayname )
 ;
END$$


DROP PROCEDURE IF EXISTS transcript_to_cdnaprobeset$$
CREATE PROCEDURE transcript_to_cdnaprobeset( arrayname TEXT, transcriptids TEXT )
BEGIN
  DROP TEMPORARY TABLE IF EXISTS tmp_data ;
  CREATE TEMPORARY TABLE tmp_data (
    ids VARCHAR( 80 ),
    INDEX USING HASH ( ids )
  ) ENGINE=MEMORY ;
  CALL tokeniser( 'tmp_data', transcriptids ) ;
  SELECT DISTINCT transcript.stable_id AS IN1, probeset.probeset_id, probeset.stable_id, probeset.array_id, probeset.array_name,
        probeset.probe_count, probeset.hit_score, probeset.gene_score, probeset.transcript_score,
        probeset.exon_score, probeset.est_gene_score, probeset.est_transcript_score, probeset.est_exon_score,
        probeset.prediction_transcript_score, probeset.prediction_exon_score, probeset.protein_score, probeset.domain_score
  FROM tmp_data
    JOIN transcript ON ( tmp_data.ids = transcript.stable_id )
    JOIN transcript_hit ON ( transcript.transcript_id = transcript_hit.transcript_id )
    JOIN probemap ON ( transcript_hit.probe_id = probemap.probe_id )
    JOIN probeset ON ( probemap.probeset_id = probeset.probeset_id AND probeset.array_name = arrayname )
 ;
END$$


DROP PROCEDURE IF EXISTS transcript_to_synonym$$
CREATE PROCEDURE transcript_to_synonym( transcriptids TEXT )
BEGIN
  DROP TEMPORARY TABLE IF EXISTS tmp_data ;
  CREATE TEMPORARY TABLE tmp_data (
    ids VARCHAR( 80 ),
    INDEX USING HASH ( ids )
  ) ENGINE=MEMORY ;
  CALL tokeniser( 'tmp_data', transcriptids ) ;
  SELECT DISTINCT transcript.stable_id AS IN1, synonym.synonym_id, synonym.synonym
  FROM tmp_data
    JOIN transcript ON ( tmp_data.ids = transcript.stable_id )
    JOIN synonym ON ( transcript.synonym_id = synonym.synonym_id )
 ;
END$$


DROP PROCEDURE IF EXISTS transcript_to_protein$$
CREATE PROCEDURE transcript_to_protein( transcriptids TEXT )
BEGIN
  DROP TEMPORARY TABLE IF EXISTS tmp_data ;
  CREATE TEMPORARY TABLE tmp_data (
    ids VARCHAR( 80 ),
    INDEX USING HASH ( ids )
  ) ENGINE=MEMORY ;
  CALL tokeniser( 'tmp_data', transcriptids ) ;
  SELECT DISTINCT transcript.stable_id AS IN1, protein.protein_id, protein.stable_id, protein.gene_id, protein.transcript_id,
        protein.chromosome_id, protein.chromosome_name, protein.start, protein.end,
        protein.strand
  FROM tmp_data
    JOIN transcript ON ( tmp_data.ids = transcript.stable_id )
    JOIN protein ON ( protein.transcript_id = transcript.transcript_id )
 ;
END$$


DROP PROCEDURE IF EXISTS transcript_to_domain$$
CREATE PROCEDURE transcript_to_domain( transcriptids TEXT )
BEGIN
  DROP TEMPORARY TABLE IF EXISTS tmp_data ;
  CREATE TEMPORARY TABLE tmp_data (
    ids VARCHAR( 80 ),
    INDEX USING HASH ( ids )
  ) ENGINE=MEMORY ;
  CALL tokeniser( 'tmp_data', transcriptids ) ;
  SELECT DISTINCT transcript.stable_id AS IN1, domain.hit_id, domain.stable_id, domain.symbol, domain.description,
        domain.model_length, domain.type, domain.protein_id, domain.seq_start,
        domain.seq_end, domain.hmm_start, domain.hmm_end, domain.bit_score,
        domain.evalue, domain.chromosome_id, domain.chromosome_name, domain.start,
        domain.end, domain.strand
  FROM tmp_data
    JOIN transcript ON ( tmp_data.ids = transcript.stable_id )
    JOIN protein ON ( protein.transcript_id = transcript.transcript_id )
    JOIN domain ON ( domain.protein_id = protein.protein_id )
 ;
END$$


DROP PROCEDURE IF EXISTS exons_in_range$$
CREATE PROCEDURE exons_in_range( chr VARCHAR(40), qstart INTEGER(10), qstop INTEGER(10), qstrand TINYINT(2) )
BEGIN
  SELECT DISTINCT exon.exon_id, exon.stable_id, exon.chromosome_id, exon.chromosome_name,
        exon.start, exon.end, exon.strand, exon.phase,
        exon.end_phase, exon.sequence
  FROM exon
  WHERE ( chromosome_name = chr ) AND ( start <= qstop ) AND ( end >= qstart ) AND ( qstrand = 0 OR strand = qstrand )
  ORDER BY start ASC ;
END$$


DROP PROCEDURE IF EXISTS all_exons$$
CREATE PROCEDURE all_exons(  )
BEGIN
  SELECT exon.exon_id, exon.stable_id, exon.chromosome_id, exon.chromosome_name, 
       exon.start, exon.end, exon.strand, exon.phase, 
       exon.end_phase, exon.sequence
    FROM exon
    ORDER BY exon_id ASC ;
END$$

DROP PROCEDURE IF EXISTS exon_details$$
CREATE PROCEDURE exon_details( ids TEXT )
BEGIN
  DROP TEMPORARY TABLE IF EXISTS tmp_data ;
  CREATE TEMPORARY TABLE tmp_data (
    ids VARCHAR( 80 ),
    INDEX USING HASH ( ids )
  ) ENGINE=MEMORY ;
  CALL tokeniser( 'tmp_data', ids ) ;
  SELECT tmp_data.ids AS IN1, exon.exon_id, exon.stable_id, exon.chromosome_id, exon.chromosome_name, 
       exon.start, exon.end, exon.strand, exon.phase, 
       exon.end_phase, exon.sequence
    FROM tmp_data
      JOIN exon ON ( exon.stable_id = tmp_data.ids ) ;
END$$


DROP PROCEDURE IF EXISTS exon_to_gene$$
CREATE PROCEDURE exon_to_gene( exonids TEXT )
BEGIN
  DROP TEMPORARY TABLE IF EXISTS tmp_data ;
  CREATE TEMPORARY TABLE tmp_data (
    ids VARCHAR( 80 ),
    INDEX USING HASH ( ids )
  ) ENGINE=MEMORY ;
  CALL tokeniser( 'tmp_data', exonids ) ;
  SELECT DISTINCT exon.stable_id AS IN1, gene.gene_id, gene.stable_id, gene.chromosome_id, gene.chromosome_name,
        gene.start, gene.end, gene.strand, gene.biotype,
        gene.status, gene.description, gene.synonym_id, gene.external_db_id,
        gene.db_display_name, gene.symbol, gene.symbol_description, gene.analysis_name
  FROM tmp_data
    JOIN exon ON ( tmp_data.ids = exon.stable_id )
    JOIN exon_transcript ON ( exon_transcript.exon_id = exon.exon_id )
    JOIN transcript ON ( exon_transcript.transcript_id = transcript.transcript_id )
    JOIN gene ON ( gene.gene_id = transcript.gene_id )
 ;
END$$


DROP PROCEDURE IF EXISTS exon_to_transcript$$
CREATE PROCEDURE exon_to_transcript( exonids TEXT )
BEGIN
  DROP TEMPORARY TABLE IF EXISTS tmp_data ;
  CREATE TEMPORARY TABLE tmp_data (
    ids VARCHAR( 80 ),
    INDEX USING HASH ( ids )
  ) ENGINE=MEMORY ;
  CALL tokeniser( 'tmp_data', exonids ) ;
  SELECT DISTINCT exon.stable_id AS IN1, transcript.transcript_id, transcript.stable_id, transcript.gene_id, transcript.chromosome_id,
        transcript.chromosome_name, transcript.start, transcript.end, transcript.strand,
        transcript.biotype, transcript.status, transcript.description, transcript.synonym_id,
        transcript.external_db_id, transcript.db_display_name, transcript.symbol, transcript.symbol_description,
        transcript.translation_start, transcript.translation_start_exon, transcript.translation_end, transcript.translation_end_exon,
        transcript.analysis_name
  FROM tmp_data
    JOIN exon ON ( tmp_data.ids = exon.stable_id )
    JOIN exon_transcript ON ( exon_transcript.exon_id = exon.exon_id )
    JOIN transcript ON ( exon_transcript.transcript_id = transcript.transcript_id )
 ;
END$$


DROP PROCEDURE IF EXISTS exon_to_probeset$$
CREATE PROCEDURE exon_to_probeset( arrayname TEXT, exonids TEXT )
BEGIN
  DROP TEMPORARY TABLE IF EXISTS tmp_data ;
  CREATE TEMPORARY TABLE tmp_data (
    ids VARCHAR( 80 ),
    INDEX USING HASH ( ids )
  ) ENGINE=MEMORY ;
  CALL tokeniser( 'tmp_data', exonids ) ;
  SELECT DISTINCT exon.stable_id AS IN1, probeset.probeset_id, probeset.stable_id, probeset.array_id, probeset.array_name,
        probeset.probe_count, probeset.hit_score, probeset.gene_score, probeset.transcript_score,
        probeset.exon_score, probeset.est_gene_score, probeset.est_transcript_score, probeset.est_exon_score,
        probeset.prediction_transcript_score, probeset.prediction_exon_score, probeset.protein_score, probeset.domain_score
  FROM tmp_data
    JOIN exon ON ( tmp_data.ids = exon.stable_id )
    JOIN hit_exon ON ( exon.exon_id = hit_exon.exon_id )
    JOIN hit ON ( hit_exon.hit_id = hit.hit_id )
    JOIN probemap ON ( hit.probe_id = probemap.probe_id )
    JOIN probeset ON ( probemap.probeset_id = probeset.probeset_id AND probeset.array_name = arrayname )
 ;
END$$


DROP PROCEDURE IF EXISTS est_genes_in_range$$
CREATE PROCEDURE est_genes_in_range( chr VARCHAR(40), qstart INTEGER(10), qstop INTEGER(10), qstrand TINYINT(2) )
BEGIN
  SELECT DISTINCT est_gene.gene_id, est_gene.stable_id, est_gene.chromosome_id, est_gene.chromosome_name,
        est_gene.start, est_gene.end, est_gene.strand, est_gene.biotype,
        est_gene.status, est_gene.description, est_gene.synonym_id, est_gene.external_db_id,
        est_gene.db_display_name, est_gene.symbol, est_gene.symbol_description
  FROM est_gene
  WHERE ( chromosome_name = chr ) AND ( start <= qstop ) AND ( end >= qstart ) AND ( qstrand = 0 OR strand = qstrand )
  ORDER BY start ASC ;
END$$


DROP PROCEDURE IF EXISTS all_est_genes$$
CREATE PROCEDURE all_est_genes(  )
BEGIN
  SELECT est_gene.gene_id, est_gene.stable_id, est_gene.chromosome_id, est_gene.chromosome_name, 
       est_gene.start, est_gene.end, est_gene.strand, est_gene.biotype, 
       est_gene.status, est_gene.description, est_gene.synonym_id, est_gene.external_db_id, 
       est_gene.db_display_name, est_gene.symbol, est_gene.symbol_description
    FROM est_gene
    ORDER BY gene_id ASC ;
END$$

DROP PROCEDURE IF EXISTS est_gene_details$$
CREATE PROCEDURE est_gene_details( ids TEXT )
BEGIN
  DROP TEMPORARY TABLE IF EXISTS tmp_data ;
  CREATE TEMPORARY TABLE tmp_data (
    ids VARCHAR( 80 ),
    INDEX USING HASH ( ids )
  ) ENGINE=MEMORY ;
  CALL tokeniser( 'tmp_data', ids ) ;
  SELECT tmp_data.ids AS IN1, est_gene.gene_id, est_gene.stable_id, est_gene.chromosome_id, est_gene.chromosome_name, 
       est_gene.start, est_gene.end, est_gene.strand, est_gene.biotype, 
       est_gene.status, est_gene.description, est_gene.synonym_id, est_gene.external_db_id, 
       est_gene.db_display_name, est_gene.symbol, est_gene.symbol_description
    FROM tmp_data
      JOIN est_gene ON ( est_gene.stable_id = tmp_data.ids ) ;
END$$


DROP PROCEDURE IF EXISTS est_gene_to_est_transcript$$
CREATE PROCEDURE est_gene_to_est_transcript( geneids TEXT )
BEGIN
  DROP TEMPORARY TABLE IF EXISTS tmp_data ;
  CREATE TEMPORARY TABLE tmp_data (
    ids VARCHAR( 80 ),
    INDEX USING HASH ( ids )
  ) ENGINE=MEMORY ;
  CALL tokeniser( 'tmp_data', geneids ) ;
  SELECT DISTINCT est_gene.stable_id AS IN1, est_transcript.transcript_id, est_transcript.stable_id, est_transcript.gene_id, est_transcript.chromosome_id,
        est_transcript.chromosome_name, est_transcript.start, est_transcript.end, est_transcript.strand,
        est_transcript.biotype, est_transcript.status, est_transcript.description, est_transcript.synonym_id,
        est_transcript.external_db_id, est_transcript.db_display_name, est_transcript.symbol, est_transcript.symbol_description,
        est_transcript.translation_start, est_transcript.translation_start_exon, est_transcript.translation_end, est_transcript.translation_end_exon
  FROM tmp_data
    JOIN est_gene ON ( tmp_data.ids = est_gene.stable_id )
    JOIN est_transcript ON ( est_gene.gene_id = est_transcript.gene_id )
 ;
END$$


DROP PROCEDURE IF EXISTS est_gene_to_est_exon$$
CREATE PROCEDURE est_gene_to_est_exon( geneids TEXT )
BEGIN
  DROP TEMPORARY TABLE IF EXISTS tmp_data ;
  CREATE TEMPORARY TABLE tmp_data (
    ids VARCHAR( 80 ),
    INDEX USING HASH ( ids )
  ) ENGINE=MEMORY ;
  CALL tokeniser( 'tmp_data', geneids ) ;
  SELECT DISTINCT est_gene.stable_id AS IN1, est_exon.exon_id, est_exon.stable_id, est_exon.chromosome_id, est_exon.chromosome_name,
        est_exon.start, est_exon.end, est_exon.strand, est_exon.phase,
        est_exon.end_phase, est_exon.sequence
  FROM tmp_data
    JOIN est_gene ON ( tmp_data.ids = est_gene.stable_id )
    JOIN est_transcript ON ( est_gene.gene_id = est_transcript.gene_id )
    JOIN est_exon_transcript ON ( est_transcript.transcript_id = est_exon_transcript.transcript_id )
    JOIN est_exon ON ( est_exon_transcript.exon_id = est_exon.exon_id )
 ;
END$$


DROP PROCEDURE IF EXISTS est_gene_to_probeset$$
CREATE PROCEDURE est_gene_to_probeset( arrayname TEXT, geneids TEXT )
BEGIN
  DROP TEMPORARY TABLE IF EXISTS tmp_data ;
  CREATE TEMPORARY TABLE tmp_data (
    ids VARCHAR( 80 ),
    INDEX USING HASH ( ids )
  ) ENGINE=MEMORY ;
  CALL tokeniser( 'tmp_data', geneids ) ;
  SELECT DISTINCT est_gene.stable_id AS IN1, probeset.probeset_id, probeset.stable_id, probeset.array_id, probeset.array_name,
        probeset.probe_count, probeset.hit_score, probeset.gene_score, probeset.transcript_score,
        probeset.exon_score, probeset.est_gene_score, probeset.est_transcript_score, probeset.est_exon_score,
        probeset.prediction_transcript_score, probeset.prediction_exon_score, probeset.protein_score, probeset.domain_score
  FROM tmp_data
    JOIN est_gene ON ( tmp_data.ids = est_gene.stable_id )
    JOIN hit_est_gene ON ( est_gene.gene_id = hit_est_gene.gene_id )
    JOIN hit ON ( hit_est_gene.hit_id = hit.hit_id )
    JOIN probemap ON ( hit.probe_id = probemap.probe_id )
    JOIN probeset ON ( probemap.probeset_id = probeset.probeset_id AND probeset.array_name = arrayname )
 ;
END$$


DROP PROCEDURE IF EXISTS est_transcripts_in_range$$
CREATE PROCEDURE est_transcripts_in_range( chr VARCHAR(40), qstart INTEGER(10), qstop INTEGER(10), qstrand TINYINT(2) )
BEGIN
  SELECT DISTINCT est_transcript.transcript_id, est_transcript.stable_id, est_transcript.gene_id, est_transcript.chromosome_id,
        est_transcript.chromosome_name, est_transcript.start, est_transcript.end, est_transcript.strand,
        est_transcript.biotype, est_transcript.status, est_transcript.description, est_transcript.synonym_id,
        est_transcript.external_db_id, est_transcript.db_display_name, est_transcript.symbol, est_transcript.symbol_description,
        est_transcript.translation_start, est_transcript.translation_start_exon, est_transcript.translation_end, est_transcript.translation_end_exon
  FROM est_transcript
  WHERE ( chromosome_name = chr ) AND ( start <= qstop ) AND ( end >= qstart ) AND ( qstrand = 0 OR strand = qstrand )
  ORDER BY start ASC ;
END$$


DROP PROCEDURE IF EXISTS all_est_transcripts$$
CREATE PROCEDURE all_est_transcripts(  )
BEGIN
  SELECT est_transcript.transcript_id, est_transcript.stable_id, est_transcript.gene_id, est_transcript.chromosome_id, 
       est_transcript.chromosome_name, est_transcript.start, est_transcript.end, est_transcript.strand, 
       est_transcript.biotype, est_transcript.status, est_transcript.description, est_transcript.synonym_id, 
       est_transcript.external_db_id, est_transcript.db_display_name, est_transcript.symbol, est_transcript.symbol_description, 
       est_transcript.translation_start, est_transcript.translation_start_exon, est_transcript.translation_end, est_transcript.translation_end_exon
    FROM est_transcript
    ORDER BY transcript_id ASC ;
END$$

DROP PROCEDURE IF EXISTS est_transcript_details$$
CREATE PROCEDURE est_transcript_details( ids TEXT )
BEGIN
  DROP TEMPORARY TABLE IF EXISTS tmp_data ;
  CREATE TEMPORARY TABLE tmp_data (
    ids VARCHAR( 80 ),
    INDEX USING HASH ( ids )
  ) ENGINE=MEMORY ;
  CALL tokeniser( 'tmp_data', ids ) ;
  SELECT tmp_data.ids AS IN1, est_transcript.transcript_id, est_transcript.stable_id, est_transcript.gene_id, est_transcript.chromosome_id, 
       est_transcript.chromosome_name, est_transcript.start, est_transcript.end, est_transcript.strand, 
       est_transcript.biotype, est_transcript.status, est_transcript.description, est_transcript.synonym_id, 
       est_transcript.external_db_id, est_transcript.db_display_name, est_transcript.symbol, est_transcript.symbol_description, 
       est_transcript.translation_start, est_transcript.translation_start_exon, est_transcript.translation_end, est_transcript.translation_end_exon
    FROM tmp_data
      JOIN est_transcript ON ( est_transcript.stable_id = tmp_data.ids ) ;
END$$


DROP PROCEDURE IF EXISTS est_transcript_to_est_gene$$
CREATE PROCEDURE est_transcript_to_est_gene( transcriptids TEXT )
BEGIN
  DROP TEMPORARY TABLE IF EXISTS tmp_data ;
  CREATE TEMPORARY TABLE tmp_data (
    ids VARCHAR( 80 ),
    INDEX USING HASH ( ids )
  ) ENGINE=MEMORY ;
  CALL tokeniser( 'tmp_data', transcriptids ) ;
  SELECT DISTINCT est_transcript.stable_id AS IN1, est_gene.gene_id, est_gene.stable_id, est_gene.chromosome_id, est_gene.chromosome_name,
        est_gene.start, est_gene.end, est_gene.strand, est_gene.biotype,
        est_gene.status, est_gene.description, est_gene.synonym_id, est_gene.external_db_id,
        est_gene.db_display_name, est_gene.symbol, est_gene.symbol_description
  FROM tmp_data
    JOIN est_transcript ON ( tmp_data.ids = est_transcript.stable_id )
    JOIN est_gene ON ( est_gene.gene_id = est_transcript.gene_id )
 ;
END$$


DROP PROCEDURE IF EXISTS est_transcript_to_est_exon$$
CREATE PROCEDURE est_transcript_to_est_exon( transcriptids TEXT )
BEGIN
  DROP TEMPORARY TABLE IF EXISTS tmp_data ;
  CREATE TEMPORARY TABLE tmp_data (
    ids VARCHAR( 80 ),
    INDEX USING HASH ( ids )
  ) ENGINE=MEMORY ;
  CALL tokeniser( 'tmp_data', transcriptids ) ;
  SELECT DISTINCT est_transcript.stable_id AS IN1, est_exon.exon_id, est_exon.stable_id, est_exon.chromosome_id, est_exon.chromosome_name,
        est_exon.start, est_exon.end, est_exon.strand, est_exon.phase,
        est_exon.end_phase, est_exon.sequence
  FROM tmp_data
    JOIN est_transcript ON ( tmp_data.ids = est_transcript.stable_id )
    JOIN est_exon_transcript ON ( est_transcript.transcript_id = est_exon_transcript.transcript_id )
    JOIN est_exon ON ( est_exon_transcript.exon_id = est_exon.exon_id )
 ;
END$$


DROP PROCEDURE IF EXISTS est_transcript_to_probeset$$
CREATE PROCEDURE est_transcript_to_probeset( arrayname TEXT, transcriptids TEXT )
BEGIN
  DROP TEMPORARY TABLE IF EXISTS tmp_data ;
  CREATE TEMPORARY TABLE tmp_data (
    ids VARCHAR( 80 ),
    INDEX USING HASH ( ids )
  ) ENGINE=MEMORY ;
  CALL tokeniser( 'tmp_data', transcriptids ) ;
  SELECT DISTINCT est_transcript.stable_id AS IN1, probeset.probeset_id, probeset.stable_id, probeset.array_id, probeset.array_name,
        probeset.probe_count, probeset.hit_score, probeset.gene_score, probeset.transcript_score,
        probeset.exon_score, probeset.est_gene_score, probeset.est_transcript_score, probeset.est_exon_score,
        probeset.prediction_transcript_score, probeset.prediction_exon_score, probeset.protein_score, probeset.domain_score
  FROM tmp_data
    JOIN est_transcript ON ( tmp_data.ids = est_transcript.stable_id )
    JOIN hit_est_transcript ON ( est_transcript.transcript_id = hit_est_transcript.transcript_id )
    JOIN hit ON ( hit_est_transcript.hit_id = hit.hit_id )
    JOIN probemap ON ( hit.probe_id = probemap.probe_id )
    JOIN probeset ON ( probemap.probeset_id = probeset.probeset_id AND probeset.array_name = arrayname )
 ;
END$$


DROP PROCEDURE IF EXISTS est_exons_in_range$$
CREATE PROCEDURE est_exons_in_range( chr VARCHAR(40), qstart INTEGER(10), qstop INTEGER(10), qstrand TINYINT(2) )
BEGIN
  SELECT DISTINCT est_exon.exon_id, est_exon.stable_id, est_exon.chromosome_id, est_exon.chromosome_name,
        est_exon.start, est_exon.end, est_exon.strand, est_exon.phase,
        est_exon.end_phase, est_exon.sequence
  FROM est_exon
  WHERE ( chromosome_name = chr ) AND ( start <= qstop ) AND ( end >= qstart ) AND ( qstrand = 0 OR strand = qstrand )
  ORDER BY start ASC ;
END$$


DROP PROCEDURE IF EXISTS all_est_exons$$
CREATE PROCEDURE all_est_exons(  )
BEGIN
  SELECT DISTINCT est_exon.exon_id, est_exon.stable_id, est_exon.chromosome_id, est_exon.chromosome_name, 
       est_exon.start, est_exon.end, est_exon.strand, est_exon.phase, 
       est_exon.end_phase, est_exon.sequence
    FROM est_exon
    ORDER BY exon_id ASC ;
END$$

DROP PROCEDURE IF EXISTS est_exon_details$$
CREATE PROCEDURE est_exon_details( ids TEXT )
BEGIN
  DROP TEMPORARY TABLE IF EXISTS tmp_data ;
  CREATE TEMPORARY TABLE tmp_data (
    ids VARCHAR( 80 ),
    INDEX USING HASH ( ids )
  ) ENGINE=MEMORY ;
  CALL tokeniser( 'tmp_data', ids ) ;
  SELECT tmp_data.ids AS IN1, est_exon.exon_id, est_exon.stable_id, est_exon.chromosome_id, est_exon.chromosome_name, 
       est_exon.start, est_exon.end, est_exon.strand, est_exon.phase, 
       est_exon.end_phase, est_exon.sequence
    FROM tmp_data
      JOIN est_exon ON ( est_exon.stable_id = tmp_data.ids ) ;
END$$


DROP PROCEDURE IF EXISTS est_exon_to_est_gene$$
CREATE PROCEDURE est_exon_to_est_gene( exonids TEXT )
BEGIN
  DROP TEMPORARY TABLE IF EXISTS tmp_data ;
  CREATE TEMPORARY TABLE tmp_data (
    ids VARCHAR( 80 ),
    INDEX USING HASH ( ids )
  ) ENGINE=MEMORY ;
  CALL tokeniser( 'tmp_data', exonids ) ;
  SELECT DISTINCT est_exon.stable_id AS IN1, est_gene.gene_id, est_gene.stable_id, est_gene.chromosome_id, est_gene.chromosome_name,
        est_gene.start, est_gene.end, est_gene.strand, est_gene.biotype,
        est_gene.status, est_gene.description, est_gene.synonym_id, est_gene.external_db_id,
        est_gene.db_display_name, est_gene.symbol, est_gene.symbol_description
  FROM tmp_data
    JOIN est_exon ON ( tmp_data.ids = est_exon.stable_id )
    JOIN est_exon_transcript ON ( est_exon_transcript.exon_id = est_exon.exon_id )
    JOIN est_transcript ON ( est_exon_transcript.transcript_id = est_transcript.transcript_id )
    JOIN est_gene ON ( est_gene.gene_id = est_transcript.gene_id )
 ;
END$$


DROP PROCEDURE IF EXISTS est_exon_to_est_transcript$$
CREATE PROCEDURE est_exon_to_est_transcript( exonids TEXT )
BEGIN
  DROP TEMPORARY TABLE IF EXISTS tmp_data ;
  CREATE TEMPORARY TABLE tmp_data (
    ids VARCHAR( 80 ),
    INDEX USING HASH ( ids )
  ) ENGINE=MEMORY ;
  CALL tokeniser( 'tmp_data', exonids ) ;
  SELECT DISTINCT est_exon.stable_id AS IN1, est_transcript.transcript_id, est_transcript.stable_id, est_transcript.gene_id, est_transcript.chromosome_id,
        est_transcript.chromosome_name, est_transcript.start, est_transcript.end, est_transcript.strand,
        est_transcript.biotype, est_transcript.status, est_transcript.description, est_transcript.synonym_id,
        est_transcript.external_db_id, est_transcript.db_display_name, est_transcript.symbol, est_transcript.symbol_description,
        est_transcript.translation_start, est_transcript.translation_start_exon, est_transcript.translation_end, est_transcript.translation_end_exon
  FROM tmp_data
    JOIN est_exon ON ( tmp_data.ids = est_exon.stable_id )
    JOIN est_exon_transcript ON ( est_exon_transcript.exon_id = est_exon.exon_id )
    JOIN est_transcript ON ( est_exon_transcript.transcript_id = est_transcript.transcript_id )
 ;
END$$


DROP PROCEDURE IF EXISTS est_exon_to_probeset$$
CREATE PROCEDURE est_exon_to_probeset( arrayname TEXT, exonids TEXT )
BEGIN
  DROP TEMPORARY TABLE IF EXISTS tmp_data ;
  CREATE TEMPORARY TABLE tmp_data (
    ids VARCHAR( 80 ),
    INDEX USING HASH ( ids )
  ) ENGINE=MEMORY ;
  CALL tokeniser( 'tmp_data', exonids ) ;
  SELECT DISTINCT est_exon.stable_id AS IN1, probeset.probeset_id, probeset.stable_id, probeset.array_id, probeset.array_name,
        probeset.probe_count, probeset.hit_score, probeset.gene_score, probeset.transcript_score,
        probeset.exon_score, probeset.est_gene_score, probeset.est_transcript_score, probeset.est_exon_score,
        probeset.prediction_transcript_score, probeset.prediction_exon_score, probeset.protein_score, probeset.domain_score
  FROM tmp_data
    JOIN est_exon ON ( tmp_data.ids = est_exon.stable_id )
    JOIN hit_est_exon ON ( est_exon.exon_id = hit_est_exon.exon_id )
    JOIN hit ON ( hit_est_exon.hit_id = hit.hit_id )
    JOIN probemap ON ( hit.probe_id = probemap.probe_id )
    JOIN probeset ON ( probemap.probeset_id = probeset.probeset_id AND probeset.array_name = arrayname )
 ;
END$$


DROP PROCEDURE IF EXISTS prediction_transcripts_in_range$$
CREATE PROCEDURE prediction_transcripts_in_range( chr VARCHAR(40), qstart INTEGER(10), qstop INTEGER(10), qstrand TINYINT(2) )
BEGIN
  SELECT DISTINCT prediction_transcript.transcript_id, prediction_transcript.stable_id, prediction_transcript.chromosome_id, prediction_transcript.chromosome_name,
        prediction_transcript.start, prediction_transcript.end, prediction_transcript.strand
  FROM prediction_transcript
  WHERE ( chromosome_name = chr ) AND ( start <= qstop ) AND ( end >= qstart ) AND ( qstrand = 0 OR strand = qstrand )
  ORDER BY start ASC ;
END$$


DROP PROCEDURE IF EXISTS all_prediction_transcripts$$
CREATE PROCEDURE all_prediction_transcripts(  )
BEGIN
  SELECT prediction_transcript.transcript_id, prediction_transcript.stable_id, prediction_transcript.chromosome_id, prediction_transcript.chromosome_name, 
       prediction_transcript.start, prediction_transcript.end, prediction_transcript.strand
    FROM prediction_transcript
    ORDER BY transcript_id ASC ;
END$$

DROP PROCEDURE IF EXISTS prediction_transcript_details$$
CREATE PROCEDURE prediction_transcript_details( ids TEXT )
BEGIN
  DROP TEMPORARY TABLE IF EXISTS tmp_data ;
  CREATE TEMPORARY TABLE tmp_data (
    ids VARCHAR( 80 ),
    INDEX USING HASH ( ids )
  ) ENGINE=MEMORY ;
  CALL tokeniser( 'tmp_data', ids ) ;
  SELECT tmp_data.ids AS IN1, prediction_transcript.transcript_id, prediction_transcript.stable_id, prediction_transcript.chromosome_id, prediction_transcript.chromosome_name, 
       prediction_transcript.start, prediction_transcript.end, prediction_transcript.strand
    FROM tmp_data
      JOIN prediction_transcript ON ( prediction_transcript.stable_id = tmp_data.ids ) ;
END$$


DROP PROCEDURE IF EXISTS prediction_transcript_to_prediction_exon$$
CREATE PROCEDURE prediction_transcript_to_prediction_exon( transcriptids TEXT )
BEGIN
  DROP TEMPORARY TABLE IF EXISTS tmp_data ;
  CREATE TEMPORARY TABLE tmp_data (
    ids VARCHAR( 80 ),
    INDEX USING HASH ( ids )
  ) ENGINE=MEMORY ;
  CALL tokeniser( 'tmp_data', transcriptids ) ;
  SELECT DISTINCT prediction_transcript.stable_id AS IN1, prediction_exon.exon_id, prediction_exon.transcript_id, prediction_exon.exon_rank, prediction_exon.chromosome_id,
        prediction_exon.chromosome_name, prediction_exon.start, prediction_exon.end, prediction_exon.strand,
        prediction_exon.start_phase, prediction_exon.sequence
  FROM tmp_data
    JOIN prediction_transcript ON ( tmp_data.ids = prediction_transcript.stable_id )
    JOIN prediction_exon ON ( prediction_exon.transcript_id = prediction_transcript.transcript_id )
 ;
END$$


DROP PROCEDURE IF EXISTS prediction_transcript_to_probeset$$
CREATE PROCEDURE prediction_transcript_to_probeset( arrayname TEXT, transcriptids TEXT )
BEGIN
  DROP TEMPORARY TABLE IF EXISTS tmp_data ;
  CREATE TEMPORARY TABLE tmp_data (
    ids VARCHAR( 80 ),
    INDEX USING HASH ( ids )
  ) ENGINE=MEMORY ;
  CALL tokeniser( 'tmp_data', transcriptids ) ;
  SELECT DISTINCT prediction_transcript.stable_id AS IN1, probeset.probeset_id, probeset.stable_id, probeset.array_id, probeset.array_name,
        probeset.probe_count, probeset.hit_score, probeset.gene_score, probeset.transcript_score,
        probeset.exon_score, probeset.est_gene_score, probeset.est_transcript_score, probeset.est_exon_score,
        probeset.prediction_transcript_score, probeset.prediction_exon_score, probeset.protein_score, probeset.domain_score
  FROM tmp_data
    JOIN prediction_transcript ON ( tmp_data.ids = prediction_transcript.stable_id )
    JOIN hit_prediction_transcript ON ( prediction_transcript.transcript_id = hit_prediction_transcript.transcript_id )
    JOIN hit ON ( hit_prediction_transcript.hit_id = hit.hit_id )
    JOIN probemap ON ( hit.probe_id = probemap.probe_id )
    JOIN probeset ON ( probemap.probeset_id = probeset.probeset_id AND probeset.array_name = arrayname )
 ;
END$$


DROP PROCEDURE IF EXISTS all_synonyms$$
CREATE PROCEDURE all_synonyms(  )
BEGIN
  SELECT synonym.synonym_id, synonym.synonym
    FROM synonym
    ORDER BY synonym_id ASC ;
END$$

DROP PROCEDURE IF EXISTS synonym_details$$
CREATE PROCEDURE synonym_details( ids TEXT )
BEGIN
  DROP TEMPORARY TABLE IF EXISTS tmp_data ;
  CREATE TEMPORARY TABLE tmp_data (
    ids VARCHAR( 80 ),
    INDEX USING HASH ( ids )
  ) ENGINE=MEMORY ;
  CALL tokeniser( 'tmp_data', ids ) ;
  SELECT tmp_data.ids AS IN1, synonym.synonym_id, synonym.synonym
    FROM tmp_data
      JOIN synonym ON ( synonym.synonym = tmp_data.ids ) ;
END$$


DROP PROCEDURE IF EXISTS synonym_to_gene$$
CREATE PROCEDURE synonym_to_gene( synonyms TEXT )
BEGIN
  DROP TEMPORARY TABLE IF EXISTS tmp_data ;
  CREATE TEMPORARY TABLE tmp_data (
    ids VARCHAR( 80 ),
    INDEX USING HASH ( ids )
  ) ENGINE=MEMORY ;
  CALL tokeniser( 'tmp_data', synonyms ) ;
  SELECT DISTINCT synonym.synonym AS IN1, gene.gene_id, gene.stable_id, gene.chromosome_id, gene.chromosome_name,
        gene.start, gene.end, gene.strand, gene.biotype,
        gene.status, gene.description, gene.synonym_id, gene.external_db_id,
        gene.db_display_name, gene.symbol, gene.symbol_description, gene.analysis_name
  FROM tmp_data
    JOIN synonym ON ( tmp_data.ids = synonym.synonym )
    JOIN gene ON ( gene.synonym_id = synonym.synonym_id )
 ;
END$$


DROP PROCEDURE IF EXISTS synonym_to_transcript$$
CREATE PROCEDURE synonym_to_transcript( synonyms TEXT )
BEGIN
  DROP TEMPORARY TABLE IF EXISTS tmp_data ;
  CREATE TEMPORARY TABLE tmp_data (
    ids VARCHAR( 80 ),
    INDEX USING HASH ( ids )
  ) ENGINE=MEMORY ;
  CALL tokeniser( 'tmp_data', synonyms ) ;
  SELECT DISTINCT synonym.synonym AS IN1, transcript.transcript_id, transcript.stable_id, transcript.gene_id, transcript.chromosome_id,
        transcript.chromosome_name, transcript.start, transcript.end, transcript.strand,
        transcript.biotype, transcript.status, transcript.description, transcript.synonym_id,
        transcript.external_db_id, transcript.db_display_name, transcript.symbol, transcript.symbol_description,
        transcript.translation_start, transcript.translation_start_exon, transcript.translation_end, transcript.translation_end_exon,
        transcript.analysis_name
  FROM tmp_data
    JOIN synonym ON ( tmp_data.ids = synonym.synonym )
    JOIN transcript ON ( transcript.synonym_id = synonym.synonym_id )
 ;
END$$


DROP PROCEDURE IF EXISTS synonym_to_est_gene$$
CREATE PROCEDURE synonym_to_est_gene( synonyms TEXT )
BEGIN
  DROP TEMPORARY TABLE IF EXISTS tmp_data ;
  CREATE TEMPORARY TABLE tmp_data (
    ids VARCHAR( 80 ),
    INDEX USING HASH ( ids )
  ) ENGINE=MEMORY ;
  CALL tokeniser( 'tmp_data', synonyms ) ;
  SELECT DISTINCT synonym.synonym AS IN1, est_gene.gene_id, est_gene.stable_id, est_gene.chromosome_id, est_gene.chromosome_name,
        est_gene.start, est_gene.end, est_gene.strand, est_gene.biotype,
        est_gene.status, est_gene.description, est_gene.synonym_id, est_gene.external_db_id,
        est_gene.db_display_name, est_gene.symbol, est_gene.symbol_description
  FROM tmp_data
    JOIN synonym ON ( tmp_data.ids = synonym.synonym )
    JOIN est_gene ON ( est_gene.synonym_id = synonym.synonym_id )
 ;
END$$


DROP PROCEDURE IF EXISTS synonym_to_est_transcript$$
CREATE PROCEDURE synonym_to_est_transcript( synonyms TEXT )
BEGIN
  DROP TEMPORARY TABLE IF EXISTS tmp_data ;
  CREATE TEMPORARY TABLE tmp_data (
    ids VARCHAR( 80 ),
    INDEX USING HASH ( ids )
  ) ENGINE=MEMORY ;
  CALL tokeniser( 'tmp_data', synonyms ) ;
  SELECT DISTINCT synonym.synonym AS IN1, est_transcript.transcript_id, est_transcript.stable_id, est_transcript.gene_id, est_transcript.chromosome_id,
        est_transcript.chromosome_name, est_transcript.start, est_transcript.end, est_transcript.strand,
        est_transcript.biotype, est_transcript.status, est_transcript.description, est_transcript.synonym_id,
        est_transcript.external_db_id, est_transcript.db_display_name, est_transcript.symbol, est_transcript.symbol_description,
        est_transcript.translation_start, est_transcript.translation_start_exon, est_transcript.translation_end, est_transcript.translation_end_exon
  FROM tmp_data
    JOIN synonym ON ( tmp_data.ids = synonym.synonym )
    JOIN est_transcript ON ( est_transcript.synonym_id = synonym.synonym_id )
 ;
END$$


DROP PROCEDURE IF EXISTS symbol_to_gene$$
CREATE PROCEDURE symbol_to_gene( symbols TEXT )
BEGIN
  DROP TEMPORARY TABLE IF EXISTS tmp_data ;
  CREATE TEMPORARY TABLE tmp_data (
    ids VARCHAR( 80 ),
    INDEX USING HASH ( ids )
  ) ENGINE=MEMORY ;
  CALL tokeniser( 'tmp_data', symbols ) ;
  SELECT DISTINCT gene.symbol AS IN1, gene.gene_id, gene.stable_id, gene.chromosome_id, gene.chromosome_name,
        gene.start, gene.end, gene.strand, gene.biotype,
        gene.status, gene.description, gene.synonym_id, gene.external_db_id,
        gene.db_display_name, gene.symbol, gene.symbol_description, gene.analysis_name
  FROM tmp_data
    JOIN gene ON ( tmp_data.ids = gene.symbol )
 ;
END$$


DROP PROCEDURE IF EXISTS symbol_to_transcript$$
CREATE PROCEDURE symbol_to_transcript( symbols TEXT )
BEGIN
  DROP TEMPORARY TABLE IF EXISTS tmp_data ;
  CREATE TEMPORARY TABLE tmp_data (
    ids VARCHAR( 80 ),
    INDEX USING HASH ( ids )
  ) ENGINE=MEMORY ;
  CALL tokeniser( 'tmp_data', symbols ) ;
  SELECT DISTINCT transcript.symbol AS IN1, transcript.transcript_id, transcript.stable_id, transcript.gene_id, transcript.chromosome_id,
        transcript.chromosome_name, transcript.start, transcript.end, transcript.strand,
        transcript.biotype, transcript.status, transcript.description, transcript.synonym_id,
        transcript.external_db_id, transcript.db_display_name, transcript.symbol, transcript.symbol_description,
        transcript.translation_start, transcript.translation_start_exon, transcript.translation_end, transcript.translation_end_exon,
        transcript.analysis_name
  FROM tmp_data
    JOIN transcript ON ( tmp_data.ids = transcript.symbol )
 ;
END$$


DROP PROCEDURE IF EXISTS symbol_to_est_gene$$
CREATE PROCEDURE symbol_to_est_gene( symbols TEXT )
BEGIN
  DROP TEMPORARY TABLE IF EXISTS tmp_data ;
  CREATE TEMPORARY TABLE tmp_data (
    ids VARCHAR( 80 ),
    INDEX USING HASH ( ids )
  ) ENGINE=MEMORY ;
  CALL tokeniser( 'tmp_data', symbols ) ;
  SELECT DISTINCT est_gene.symbol AS IN1, est_gene.gene_id, est_gene.stable_id, est_gene.chromosome_id, est_gene.chromosome_name,
        est_gene.start, est_gene.end, est_gene.strand, est_gene.biotype,
        est_gene.status, est_gene.description, est_gene.synonym_id, est_gene.external_db_id,
        est_gene.db_display_name, est_gene.symbol, est_gene.symbol_description
  FROM tmp_data
    JOIN est_gene ON ( tmp_data.ids = est_gene.symbol )
 ;
END$$


DROP PROCEDURE IF EXISTS symbol_to_est_transcript$$
CREATE PROCEDURE symbol_to_est_transcript( symbols TEXT )
BEGIN
  DROP TEMPORARY TABLE IF EXISTS tmp_data ;
  CREATE TEMPORARY TABLE tmp_data (
    ids VARCHAR( 80 ),
    INDEX USING HASH ( ids )
  ) ENGINE=MEMORY ;
  CALL tokeniser( 'tmp_data', symbols ) ;
  SELECT DISTINCT est_transcript.symbol AS IN1, est_transcript.transcript_id, est_transcript.stable_id, est_transcript.gene_id, est_transcript.chromosome_id,
        est_transcript.chromosome_name, est_transcript.start, est_transcript.end, est_transcript.strand,
        est_transcript.biotype, est_transcript.status, est_transcript.description, est_transcript.synonym_id,
        est_transcript.external_db_id, est_transcript.db_display_name, est_transcript.symbol, est_transcript.symbol_description,
        est_transcript.translation_start, est_transcript.translation_start_exon, est_transcript.translation_end, est_transcript.translation_end_exon
  FROM tmp_data
    JOIN est_transcript ON ( tmp_data.ids = est_transcript.symbol )
 ;
END$$


DROP PROCEDURE IF EXISTS variations_in_range$$
CREATE PROCEDURE variations_in_range( chr VARCHAR(40), qstart INTEGER(10), qstop INTEGER(10), qstrand TINYINT(2) )
BEGIN
  SELECT DISTINCT variation.variation_feature_id, variation.stable_id, variation.chromosome_id, variation.start,
        variation.end, variation.strand, variation.allele_string, variation.allele_freq,
        variation.minor_allele, variation.attrib_class, variation.source, variation.validation_status,
        transcript_variation.consequence_types, transcript_variation.pep_allele_string, transcript_variation.translation_start, transcript_variation.translation_end,
        transcript_variation.sift_score, transcript_variation.polyphen_score, transcript_variation.feature_stable_id, chromosome.name AS chromosome_name
  FROM variation
    JOIN chromosome ON ( variation.chromosome_id = chromosome.chromosome_id )
    LEFT JOIN transcript_variation ON ( variation.variation_feature_id = transcript_variation.variation_feature_id )
  WHERE ( chromosome.name = chr ) AND ( start >= qstart AND start < qstop ) AND ( qstrand = 0 OR strand = qstrand )
  ORDER BY start ASC ;
END$$


DROP PROCEDURE IF EXISTS variation_details$$
CREATE PROCEDURE variation_details( ids TEXT )
BEGIN
  DROP TEMPORARY TABLE IF EXISTS tmp_data ;
  CREATE TEMPORARY TABLE tmp_data (
    ids VARCHAR( 80 ),
    INDEX USING HASH ( ids )
  ) ENGINE=MEMORY ;
  CALL tokeniser( 'tmp_data', ids ) ;
  SELECT tmp_data.ids AS IN1, variation.variation_feature_id, variation.stable_id, variation.chromosome_id, variation.start, 
       variation.end, variation.strand, variation.allele_string, variation.allele_freq, 
       variation.minor_allele, variation.attrib_class, variation.source, variation.validation_status, 
       transcript_variation.variation_feature_id, transcript_variation.consequence_types, transcript_variation.pep_allele_string, transcript_variation.translation_start, 
       transcript_variation.translation_end, transcript_variation.sift_score, transcript_variation.polyphen_score, transcript_variation.feature_stable_id
    FROM tmp_data
      JOIN variation ON ( variation.stable_id = tmp_data.ids )
      LEFT JOIN transcript_variation ON ( variation.variation_feature_id = transcript_variation.variation_feature_id ) ;
END$$


DROP PROCEDURE IF EXISTS variation_to_transcript$$
CREATE PROCEDURE variation_to_transcript( variationids TEXT )
BEGIN
  DROP TEMPORARY TABLE IF EXISTS tmp_data ;
  CREATE TEMPORARY TABLE tmp_data (
    ids VARCHAR( 80 ),
    INDEX USING HASH ( ids )
  ) ENGINE=MEMORY ;
  CALL tokeniser( 'tmp_data', variationids ) ;
  SELECT DISTINCT transcript.stable_id AS IN1, transcript.transcript_id, transcript.stable_id, transcript.gene_id, transcript.chromosome_id,
        transcript.chromosome_name, transcript.start, transcript.end, transcript.strand,
        transcript.biotype, transcript.status, transcript.description, transcript.synonym_id,
        transcript.external_db_id, transcript.db_display_name, transcript.symbol, transcript.symbol_description,
        transcript.translation_start, transcript.translation_start_exon, transcript.translation_end, transcript.translation_end_exon,
        transcript.analysis_name
  FROM tmp_data
    JOIN variation ON ( tmp_data.ids = variation.stable_id )
    JOIN transcript_variation ON ( variation.variation_feature_id = transcript_variation.variation_feature_id )
    JOIN transcript ON ( transcript_variation.feature_stable_id = transcript.stable_id )
 ;
END$$

DELIMITER ;
